import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import BaseUploadServer, BaseUserGroupFields
from vkbottle_types.responses.base import (
    BaseBoolResponse,
    BaseGetUploadServerResponse,
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.bugtracker import *  # noqa: F401,F403  # type: ignore


class BugtrackerCategory(BaseCategory):
    async def add_company_groups_members(
        self,
        company_group_ids: typing.List[int],
        company_id: int,
        user_ids: typing.List[int],
        **kwargs: typing.Any,
    ) -> BugtrackerAddCompanyGroupsMembersResponseModel:
        """Method `bugtracker.addCompanyGroupsMembers()`

        :param company_group_ids:
        :param company_id:
        :param user_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("bugtracker.addCompanyGroupsMembers", params)
        model = BugtrackerAddCompanyGroupsMembersResponse
        return model(**response).response

    async def add_company_members(
        self,
        company_id: int,
        user_ids: typing.List[int],
        **kwargs: typing.Any,
    ) -> BugtrackerAddCompanyMembersResponseModel:
        """Method `bugtracker.addCompanyMembers()`

        :param company_id:
        :param user_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("bugtracker.addCompanyMembers", params)
        model = BugtrackerAddCompanyMembersResponse
        return model(**response).response

    async def change_bugreport_status(
        self,
        bugreport_id: int,
        comment: typing.Optional[str] = None,
        from_statuses: typing.Optional[typing.List[int]] = None,
        not_in_statuses: typing.Optional[typing.List[int]] = None,
        status: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `bugtracker.changeBugreportStatus()`

        :param bugreport_id:
        :param comment:
        :param from_statuses:
        :param not_in_statuses:
        :param status:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("bugtracker.changeBugreportStatus", params)
        model = BaseBoolResponse
        return model(**response).response

    async def create_comment(
        self,
        bugreport_id: int,
        force: typing.Optional[bool] = None,
        hidden: typing.Optional[bool] = None,
        text: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> BugtrackerCreateCommentResponseModel:
        """Method `bugtracker.createComment()`

        :param bugreport_id:
        :param force:
        :param hidden:
        :param text:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("bugtracker.createComment", params)
        model = BugtrackerCreateCommentResponse
        return model(**response).response

    async def get_bugreport_by_id(
        self,
        bugreport_id: int,
        extended: typing.Optional[bool] = None,
        fields: typing.Optional[typing.List[BaseUserGroupFields]] = None,
        **kwargs: typing.Any,
    ) -> BugtrackerGetBugreportByIdResponseModel:
        """Method `bugtracker.getBugreportById()`

        :param bugreport_id:
        :param extended:
        :param fields:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("bugtracker.getBugreportById", params)
        model = BugtrackerGetBugreportByIdResponse
        return model(**response).response

    async def get_company_group_members(
        self,
        company_group_id: int,
        company_id: int,
        count: typing.Optional[int] = None,
        extended: typing.Optional[bool] = None,
        fields: typing.Optional[typing.List[BaseUserGroupFields]] = None,
        filter_name: typing.Optional[str] = None,
        offset: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BugtrackerGetCompanyGroupMembersResponseModel:
        """Method `bugtracker.getCompanyGroupMembers()`

        :param company_group_id:
        :param company_id:
        :param count:
        :param extended:
        :param fields:
        :param filter_name:
        :param offset:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("bugtracker.getCompanyGroupMembers", params)
        model = BugtrackerGetCompanyGroupMembersResponse
        return model(**response).response

    async def get_company_members(
        self,
        company_id: int,
        count: typing.Optional[int] = None,
        extended: typing.Optional[bool] = None,
        extra: typing.Optional[bool] = None,
        fields: typing.Optional[typing.List[BaseUserGroupFields]] = None,
        filter_member_ids: typing.Optional[typing.List[int]] = None,
        filter_name: typing.Optional[str] = None,
        filter_not_group: typing.Optional[int] = None,
        filter_role: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BugtrackerGetCompanyMembersResponseModel:
        """Method `bugtracker.getCompanyMembers()`

        :param company_id:
        :param count:
        :param extended:
        :param extra:
        :param fields:
        :param filter_member_ids:
        :param filter_name:
        :param filter_not_group:
        :param filter_role:
        :param offset:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("bugtracker.getCompanyMembers", params)
        model = BugtrackerGetCompanyMembersResponse
        return model(**response).response

    async def get_download_version_url(
        self,
        product_id: int,
        version_id: int,
        ttl: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BugtrackerGetDownloadVersionUrlResponseModel:
        """Method `bugtracker.getDownloadVersionUrl()`

        :param product_id:
        :param version_id:
        :param ttl:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("bugtracker.getDownloadVersionUrl", params)
        model = BugtrackerGetDownloadVersionUrlResponse
        return model(**response).response

    async def get_product_build_upload_server(
        self,
        product_id: int,
        **kwargs: typing.Any,
    ) -> "BaseUploadServer":
        """Method `bugtracker.getProductBuildUploadServer()`

        :param product_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("bugtracker.getProductBuildUploadServer", params)
        model = BaseGetUploadServerResponse
        return model(**response).response

    async def remove_company_group_member(
        self,
        company_group_id: int,
        company_id: int,
        user_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `bugtracker.removeCompanyGroupMember()`

        :param company_group_id:
        :param company_id:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("bugtracker.removeCompanyGroupMember", params)
        model = BaseOkResponse
        return model(**response).response

    async def remove_company_member(
        self,
        company_id: int,
        user_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `bugtracker.removeCompanyMember()`

        :param company_id:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("bugtracker.removeCompanyMember", params)
        model = BaseOkResponse
        return model(**response).response

    async def save_product_version(
        self,
        title: str,
        product_id: typing.Optional[int] = None,
        release_notes: typing.Optional[str] = None,
        set_rft: typing.Optional[bool] = None,
        version_id: typing.Optional[int] = None,
        visible: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `bugtracker.saveProductVersion()`

        :param title:
        :param product_id:
        :param release_notes:
        :param set_rft:
        :param version_id:
        :param visible:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("bugtracker.saveProductVersion", params)
        model = BaseOkResponse
        return model(**response).response

    async def set_company_member_role(
        self,
        company_id: int,
        role: int,
        user_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `bugtracker.setCompanyMemberRole()`

        :param company_id:
        :param role:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("bugtracker.setCompanyMemberRole", params)
        model = BaseOkResponse
        return model(**response).response

    async def set_product_is_over(
        self,
        product_id: int,
        is_over: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `bugtracker.setProductIsOver()`

        :param product_id:
        :param is_over:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("bugtracker.setProductIsOver", params)
        model = BaseOkResponse
        return model(**response).response


__all__ = ("BugtrackerCategory",)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.likes import *  # noqa: F401,F403  # type: ignore


class LikesCategory(BaseCategory):
    async def add(
        self,
        item_id: int,
        type: str,
        access_key: typing.Optional[str] = None,
        from_group: typing.Optional[bool] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> LikesAddResponseModel:
        """Method `likes.add()`

        :param item_id: Object ID.
        :param type: Object type: 'post' - post on user or community wall, 'comment' - comment on a wall post, 'photo' - photo, 'audio' - audio, 'video' - video, 'story' - story, 'note' - note, 'photo_comment' - comment on the photo, 'video_comment' - comment on the video, 'topic_comment' - comment in the discussion, 'sitepage' - page of the site where the [vk.com/dev/Like|Like widget] is installed
        :param access_key: Access key required for an object owned by a private entity.
        :param from_group: Impersonate group
        :param owner_id: ID of the user or community that owns the object.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("likes.add", params)
        model = LikesAddResponse
        return model(**response).response

    async def delete(
        self,
        item_id: int,
        type: str,
        access_key: typing.Optional[str] = None,
        from_group: typing.Optional[bool] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> LikesDeleteResponseModel:
        """Method `likes.delete()`

        :param item_id: Object ID.
        :param type: Object type: 'post' - post on user or community wall, 'comment' - comment on a wall post, 'photo' - photo, 'audio' - audio, 'video' - video, 'story' - story, 'note' - note, 'photo_comment' - comment on the photo, 'video_comment' - comment on the video, 'topic_comment' - comment in the discussion, 'sitepage' - page of the site where the [vk.com/dev/Like|Like widget] is installed
        :param access_key: Access key required for an object owned by a private entity.
        :param from_group: Impersonate group
        :param owner_id: ID of the user or community that owns the object.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("likes.delete", params)
        model = LikesDeleteResponse
        return model(**response).response

    @typing.overload
    async def get_list(
        self,
        type: str,
        extended: typing.Literal[True],
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[str]] = None,
        filter: typing.Optional[str] = None,
        friends_only: typing.Optional[int] = None,
        item_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        page_url: typing.Optional[str] = None,
        skip_own: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> LikesGetListExtendedResponseModel: ...

    @typing.overload
    async def get_list(
        self,
        type: str,
        extended: typing.Optional[typing.Literal[False]] = None,
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[str]] = None,
        filter: typing.Optional[str] = None,
        friends_only: typing.Optional[int] = None,
        item_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        page_url: typing.Optional[str] = None,
        skip_own: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> LikesGetListResponseModel: ...

    async def get_list(
        self,
        type: str,
        extended: typing.Optional[bool] = None,
        count: typing.Optional[int] = None,
        fields: typing.Optional[typing.List[str]] = None,
        filter: typing.Optional[str] = None,
        friends_only: typing.Optional[int] = None,
        item_id: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        page_url: typing.Optional[str] = None,
        skip_own: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> typing.Union[LikesGetListExtendedResponseModel, LikesGetListResponseModel]:
        """Method `likes.getList()`

        :param type: , Object type: 'post' - post on user or community wall, 'comment' - comment on a wall post, 'photo' - photo, 'audio' - audio, 'video' - video, 'story' - story, 'note' - note, 'photo_comment' - comment on the photo, 'video_comment' - comment on the video, 'topic_comment' - comment in the discussion, 'sitepage' - page of the site where the [vk.com/dev/Like|Like widget] is installed
        :param extended: Specifies whether extended information will be returned. '1' - to return extended information about users and communities from the 'Likes' list, '0' - to return no additional information (default)
        :param count: Number of user IDs to return (maximum '1000'). Default is '100' if 'friends_only' is set to '0', otherwise, the default is '10' if 'friends_only' is set to '1'.
        :param fields:
        :param filter: Filters to apply: 'likes' - returns information about all users who liked the object (default), 'copies' - returns information only about users who told their friends about the object
        :param friends_only: Specifies which users are returned: '1' - to return only the current user's friends, '0' - to return all users (default)
        :param item_id: Object ID. If 'type' is set as 'sitepage', 'item_id' can include the 'page_id' parameter value used during initialization of the [vk.com/dev/Like|Like widget].
        :param offset: Offset needed to select a specific subset of users.
        :param owner_id: ID of the user, community, or application that owns the object. If the 'type' parameter is set as 'sitepage', the application ID is passed as 'owner_id'. Use negative value for a community id. If the 'type' parameter is not set, the 'owner_id' is assumed to be either the current user or the same application ID as if the 'type' parameter was set to 'sitepage'.
        :param page_url: URL of the page where the [vk.com/dev/Like|Like widget] is installed. Used instead of the 'item_id' parameter.
        :param skip_own:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("likes.getList", params)
        model = self.get_model(
            ((("extended",), LikesGetListExtendedResponse),),
            default=LikesGetListResponse,
            params=params,
        )
        return model(**response).response

    async def is_liked(
        self,
        item_id: int,
        type: str,
        owner_id: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> LikesIsLikedResponseModel:
        """Method `likes.isLiked()`

        :param item_id: Object ID.
        :param type: Object type: 'post' - post on user or community wall, 'comment' - comment on a wall post, 'photo' - photo, 'audio' - audio, 'video' - video, 'story' - story, 'note' - note, 'photo_comment' - comment on the photo, 'video_comment' - comment on the video, 'topic_comment' - comment in the discussion
        :param owner_id: ID of the user or community that owns the object.
        :param user_id: User ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("likes.isLiked", params)
        model = LikesIsLikedResponse
        return model(**response).response


__all__ = ("LikesCategory",)



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import DonutDonatorSubscriptionInfo, GroupsGroupFull, UsersUserFull
from vkbottle_types.responses.base_response import BaseResponse


class DonutGetSubscriptionResponse(BaseResponse):
    response: "DonutDonatorSubscriptionInfo" = Field()


class DonutGetSubscriptionsResponseModel(BaseModel):
    subscriptions: typing.List["DonutDonatorSubscriptionInfo"] = Field()
    count: typing.Optional[int] = Field(
        default=None,
    )
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )


class DonutGetSubscriptionsResponse(BaseResponse):
    response: "DonutGetSubscriptionsResponseModel" = Field()



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import StatusStatus
from vkbottle_types.responses.base import (
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.status import *  # noqa: F401,F403  # type: ignore


class StatusCategory(BaseCategory):
    async def get(
        self,
        group_id: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> "StatusStatus":
        """Method `status.get()`

        :param group_id:
        :param user_id: User ID or community ID. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("status.get", params)
        model = StatusGetResponse
        return model(**response).response

    async def set(
        self,
        group_id: typing.Optional[int] = None,
        text: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `status.set()`

        :param group_id: Identifier of a community to set a status in. If left blank the status is set to current user.
        :param text: Text of the new status.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("status.set", params)
        model = BaseOkResponse
        return model(**response).response


__all__ = ("StatusCategory",)



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    AppsApp,
    GroupsGroup,
    NotificationsNotificationItem,
    NotificationsSendMessageItem,
    PhotosPhoto,
    UsersUser,
    VideoVideoFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class NotificationsGetResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["NotificationsNotificationItem"] = Field()
    profiles: typing.Optional[typing.List["UsersUser"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroup"]] = Field(
        default=None,
    )
    last_viewed: typing.Optional[int] = Field(
        default=None,
    )
    photos: typing.Optional[typing.List["PhotosPhoto"]] = Field(
        default=None,
    )
    videos: typing.Optional[typing.List["VideoVideoFull"]] = Field(
        default=None,
    )
    apps: typing.Optional[typing.List["AppsApp"]] = Field(
        default=None,
    )
    next_from: typing.Optional[str] = Field(
        default=None,
    )
    ttl: typing.Optional[int] = Field(
        default=None,
    )


class NotificationsGetResponse(BaseResponse):
    response: "NotificationsGetResponseModel" = Field()


class NotificationsSendMessageResponse(BaseResponse):
    response: typing.List["NotificationsSendMessageItem"] = Field()



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import (
    BaseUploadServer,
    PollsBackground,
    PollsFieldsVoters,
    PollsPoll,
    PollsPollExtended,
    PollsVoters,
    UsersFields,
)
from vkbottle_types.responses.base import (
    BaseBoolResponse,
    BaseGetUploadServerResponse,
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.polls import *  # noqa: F401,F403  # type: ignore


class PollsCategory(BaseCategory):
    async def add_vote(
        self,
        answer_ids: typing.List[int],
        poll_id: int,
        is_board: typing.Optional[bool] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `polls.addVote()`

        :param answer_ids:
        :param poll_id: Poll ID.
        :param is_board:
        :param owner_id: ID of the user or community that owns the poll. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("polls.addVote", params)
        model = BaseBoolResponse
        return model(**response).response

    async def create(
        self,
        add_answers: typing.Optional[str] = None,
        app_id: typing.Optional[int] = None,
        background_id: typing.Optional[str] = None,
        disable_unvote: typing.Optional[bool] = None,
        end_date: typing.Optional[int] = None,
        is_anonymous: typing.Optional[bool] = None,
        is_multiple: typing.Optional[bool] = None,
        owner_id: typing.Optional[int] = None,
        photo_id: typing.Optional[int] = None,
        question: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> "PollsPoll":
        """Method `polls.create()`

        :param add_answers: available answers list, for example: " ["yes","no","maybe"]", There can be from 1 to 10 answers.
        :param app_id:
        :param background_id:
        :param disable_unvote:
        :param end_date:
        :param is_anonymous: '1' - anonymous poll, participants list is hidden,, '0' - public poll, participants list is available,, Default value is '0'.
        :param is_multiple:
        :param owner_id: If a poll will be added to a communty it is required to send a negative group identifier. Current user by default.
        :param photo_id:
        :param question: question text
        """

        params = self.get_set_params(locals())
        response = await self.api.request("polls.create", params)
        model = PollsCreateResponse
        return model(**response).response

    async def delete_vote(
        self,
        poll_id: int,
        is_board: typing.Optional[bool] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `polls.deleteVote()`

        :param poll_id: Poll ID.
        :param is_board:
        :param owner_id: ID of the user or community that owns the poll. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("polls.deleteVote", params)
        model = BaseBoolResponse
        return model(**response).response

    async def edit(
        self,
        poll_id: int,
        add_answers: typing.Optional[str] = None,
        background_id: typing.Optional[str] = None,
        delete_answers: typing.Optional[str] = None,
        edit_answers: typing.Optional[str] = None,
        end_date: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        photo_id: typing.Optional[int] = None,
        question: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `polls.edit()`

        :param poll_id: edited poll's id
        :param add_answers: answers list, for example: , "["yes","no","maybe"]"
        :param background_id:
        :param delete_answers: list of answer ids to be deleted. For example: "[382967099, 382967103]"
        :param edit_answers: object containing answers that need to be edited,, key - answer id, value - new answer text. Example: {"382967099":"option1", "382967103":"option2"}"
        :param end_date:
        :param owner_id: poll owner id
        :param photo_id:
        :param question: new question text
        """

        params = self.get_set_params(locals())
        response = await self.api.request("polls.edit", params)
        model = BaseOkResponse
        return model(**response).response

    async def get_backgrounds(
        self,
        **kwargs: typing.Any,
    ) -> typing.List[PollsBackground]:
        """Method `polls.getBackgrounds()`"""

        params = self.get_set_params(locals())
        response = await self.api.request("polls.getBackgrounds", params)
        model = PollsGetBackgroundsResponse
        return model(**response).response

    async def get_by_id(
        self,
        poll_id: int,
        extended: typing.Optional[bool] = None,
        fields: typing.Optional[typing.List[str]] = None,
        friends_count: typing.Optional[int] = None,
        is_board: typing.Optional[bool] = None,
        name_case: typing.Optional[str] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> "PollsPollExtended":
        """Method `polls.getById()`

        :param poll_id: Poll ID.
        :param extended:
        :param fields:
        :param friends_count:
        :param is_board: '1' - poll is in a board, '0' - poll is on a wall. '0' by default.
        :param name_case:
        :param owner_id: ID of the user or community that owns the poll. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("polls.getById", params)
        model = PollsGetByIdResponse
        return model(**response).response

    async def get_photo_upload_server(
        self,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> "BaseUploadServer":
        """Method `polls.getPhotoUploadServer()`

        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("polls.getPhotoUploadServer", params)
        model = BaseGetUploadServerResponse
        return model(**response).response

    @typing.overload
    async def get_voters(
        self,
        answer_ids: typing.List[int],
        poll_id: int,
        fields: typing.List[UsersFields],
        count: typing.Optional[int] = None,
        friends_only: typing.Optional[bool] = None,
        is_board: typing.Optional[bool] = None,
        name_case: typing.Optional[str] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.List[PollsFieldsVoters]: ...

    @typing.overload
    async def get_voters(
        self,
        answer_ids: typing.List[int],
        poll_id: int,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        count: typing.Optional[int] = None,
        friends_only: typing.Optional[bool] = None,
        is_board: typing.Optional[bool] = None,
        name_case: typing.Optional[str] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.List[PollsVoters]: ...

    async def get_voters(
        self,
        answer_ids: typing.List[int],
        poll_id: int,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        count: typing.Optional[int] = None,
        friends_only: typing.Optional[bool] = None,
        is_board: typing.Optional[bool] = None,
        name_case: typing.Optional[str] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.Union[typing.List[PollsVoters], typing.List[PollsFieldsVoters]]:
        """Method `polls.getVoters()`

        :param answer_ids: Answer IDs.
        :param poll_id: Poll ID.
        :param fields: Profile fields to return. Sample values: 'nickname', 'screen_name', 'sex', 'bdate (birthdate)', 'city', 'country', 'timezone', 'photo', 'photo_medium', 'photo_big', 'has_mobile', 'rate', 'contacts', 'education', 'online', 'counters'.
        :param count: Number of user IDs to return (if the 'friends_only' parameter is not set, maximum '1000', otherwise '10'). '100' - (default)
        :param friends_only: '1' - to return only current user's friends, '0' - to return all users (default),
        :param is_board:
        :param name_case: Case for declension of user name and surname: , 'nom' - nominative (default) , 'gen' - genitive , 'dat' - dative , 'acc' - accusative , 'ins' - instrumental , 'abl' - prepositional
        :param offset: Offset needed to return a specific subset of voters. '0' - (default)
        :param owner_id: ID of the user or community that owns the poll. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("polls.getVoters", params)
        model = self.get_model(
            ((("fields",), PollsGetVotersFieldsResponse),),
            default=PollsGetVotersResponse,
            params=params,
        )
        return model(**response).response

    async def save_photo(
        self,
        hash: typing.Optional[str] = None,
        photo: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> "PollsBackground":
        """Method `polls.savePhoto()`

        :param hash:
        :param photo:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("polls.savePhoto", params)
        model = PollsSavePhotoResponse
        return model(**response).response


__all__ = ("PollsCategory",)



from typing import Any, List, Optional

import pydantic

from vkbottle_types.base_model import BaseModel
from vkbottle_types.objects import (
    AudioAudio,
    BaseBoolInt,
    BoardTopicComment,
    CallbackGroupJoinType,
    CallbackGroupMarket,
    CallbackGroupOfficerRole,
    CallbackLikeAddRemoveObjectType,
    ClientInfoForBots,
    GroupsGroupAudio,
    GroupsGroupFullAgeLimits,
    GroupsGroupIsClosed,
    GroupsGroupPhotos,
    GroupsGroupVideo,
    GroupsGroupWall,
    MarketOrder,
    MessagesMessage,
    PhotosPhoto,
    VideoVideo,
    WallWallComment,
    WallWallpostFull,
)


class BaseEventObject(BaseModel):
    model_config = pydantic.ConfigDict(frozen=False)


class MessageNewObject(BaseEventObject):
    client_info: Optional["ClientInfoForBots"] = None
    message: Optional["MessagesMessage"] = None


class MessageReplyObject(BaseEventObject, MessagesMessage):
    pass


class MessageEditObject(BaseEventObject, MessagesMessage):
    pass


class MessageAllowObject(BaseEventObject):
    key: str
    user_id: int


class MessageDenyObject(BaseEventObject):
    user_id: int


class MessageTypingStateObject(BaseEventObject):
    state: Optional[str] = None
    from_id: Optional[int] = None
    to_id: Optional[int] = None


class MessageEventObject(BaseEventObject):
    user_id: int
    peer_id: int
    event_id: str
    payload: Optional[dict] = None
    conversation_message_id: Optional[int] = None


class PhotoNewObject(BaseEventObject, PhotosPhoto):
    pass


class PhotoCommentNewObject(BaseEventObject, WallWallComment):
    photo_id: int  # type: ignore
    photo_owner_id: int


class PhotoCommentEditObject(PhotoCommentNewObject):
    pass


class PhotoCommentRestoreObject(PhotoCommentNewObject):
    pass


class PhotoCommentDeleteObject(BaseEventObject):
    id: int
    owner_id: int
    photo_id: int
    user_id: int


class AudioNewObject(BaseEventObject, AudioAudio):
    pass


class VideoNewObject(BaseEventObject, VideoVideo):
    pass


class VideoCommentNewObject(BaseEventObject, WallWallComment):
    video_id: int  # type: ignore
    video_owner_id: int


class VideoCommentEditObject(VideoCommentNewObject):
    pass


class VideoCommentRestoreObject(VideoCommentNewObject):
    pass


class VideoCommentDeleteObject(BaseEventObject):
    id: int
    deleter_id: int
    owner_id: int
    user_id: int
    video_id: int


class WallPostNewObject(BaseEventObject, WallWallpostFull):
    postponed_id: Optional[int] = None


class WallRepostObject(WallPostNewObject):
    pass


class WallReplyNewObject(BaseEventObject, WallWallComment):
    post_id: Optional[int] = None
    post_owner_id: Optional[int] = None


class WallReplyEditObject(WallReplyNewObject):
    pass


class WallReplyRestoreObject(WallReplyNewObject):
    pass


class WallReplyDeleteObject(BaseEventObject):
    owner_id: Optional[int] = None
    id: Optional[int] = None
    deleter_id: Optional[int] = None
    post_id: Optional[int] = None


class LikeAddObject(BaseEventObject):
    liker_id: int
    object_id: int
    object_owner_id: int
    object_type: Optional["CallbackLikeAddRemoveObjectType"] = None
    post_id: int
    thread_reply_id: Optional[int] = None


class LikeRemoveObject(LikeAddObject):
    pass


class LeadFormAnswerModel(BaseModel):
    key: str
    question: str
    answer: Optional[str] = None


class LeadFormsNewObject(BaseEventObject):
    lead_id: int
    group_id: int
    form_id: int
    user_id: int
    form_name: str
    answers: Optional[List["LeadFormAnswerModel"]] = None


class BoardPostNewObject(BaseEventObject, BoardTopicComment):
    topic_id: Optional[int] = None
    topic_owner_id: Optional[int] = None


class BoardPostEditObject(BoardPostNewObject):
    pass


class BoardPostRestoreObject(BoardPostNewObject):
    pass


class BoardPostDeleteObject(BaseEventObject):
    id: int
    topic_id: int
    topic_owner_id: int


class MarketCommentNewObject(BaseEventObject):
    date: int
    from_id: int
    id: int
    market_owner_id: Optional[int] = None
    photo_id: Optional[int] = None
    text: Optional[str] = None


class MarketCommentEditObject(MarketCommentNewObject):
    pass


class MarketCommentRestoreObject(MarketCommentNewObject):
    pass


class MarketCommentDeleteObject(BaseEventObject):
    id: int
    item_id: int
    owner_id: int
    user_id: int


class MarketOrderNewObject(BaseEventObject, MarketOrder):
    pass


class MarketOrderEditObject(MarketOrderNewObject):
    pass


class GroupLeaveObject(BaseEventObject):
    self: Optional["BaseBoolInt"] = None
    user_id: Optional[int] = None


class GroupJoinObject(BaseEventObject):
    join_type: "CallbackGroupJoinType"
    user_id: int


class UserBlockObject(BaseEventObject):
    admin_id: int
    comment: Optional[str] = None
    reason: int
    unblock_date: int
    user_id: int


class UserUnblockObject(BaseEventObject):
    admin_id: int
    by_end_date: int
    user_id: int


class PollVoteNewObject(BaseEventObject):
    option_id: int
    owner_id: int
    poll_id: int
    user_id: int


class GroupOfficersEditObject(BaseEventObject):
    admin_id: int
    level_new: "CallbackGroupOfficerRole"
    level_old: "CallbackGroupOfficerRole"
    user_id: int


class GroupSettingsChangesObject(BaseEventObject):
    access: Optional["GroupsGroupIsClosed"] = None
    age_limits: Optional["GroupsGroupFullAgeLimits"] = None
    description: Optional[str] = None
    enable_audio: Optional["GroupsGroupAudio"] = None
    enable_market: Optional["CallbackGroupMarket"] = None
    enable_photo: Optional["GroupsGroupPhotos"] = None
    enable_status_default: Optional["GroupsGroupWall"] = None
    enable_video: Optional["GroupsGroupVideo"] = None
    public_category: Optional[int] = None
    public_subcategory: Optional[int] = None
    screen_name: Optional[str] = None
    title: Optional[str] = None
    website: Optional[str] = None
    old_value: Any
    new_value: Any


class GroupChangeSettingsObject(BaseEventObject):
    changes: Optional[GroupSettingsChangesObject] = None
    user_id: int


class GroupChangePhotoObject(BaseEventObject):
    photo: "PhotosPhoto"
    user_id: int


class VkpayTransactionObject(BaseEventObject):
    amount: Optional[int] = None
    date: Optional[int] = None
    description: Optional[str] = None
    from_id: Optional[int] = None


class AppPayloadObject(BaseEventObject):
    user_id: Optional[int] = None
    app_id: Optional[int] = None
    payload: Optional[str] = None
    group_id: Optional[int] = None


class DonutSubscriptionCreateObject(BaseEventObject):
    amount: int
    amount_without_fee: float
    user_id: Optional[int] = None


class DonutSubscriptionProlongedObject(BaseEventObject):
    pass


class DonutSubscriptionExpiredObject(BaseEventObject):
    user_id: Optional[int] = None


class DonutSubscriptionCancelledObject(BaseEventObject):
    user_id: Optional[int] = None


class DonutSubscriptionPriceChangedObject(BaseEventObject):
    amount_diff: Optional[float] = None
    amount_diff_without_fee: Optional[float] = None
    amount_new: int
    amount_old: int
    user_id: Optional[int] = None


class DonutMoneyWithdrawObject(BaseEventObject):
    amount: float
    amount_without_fee: float


class DonutMoneyWithdrawErrorObject(BaseEventObject):
    reason: str


class MessageReactionEventObject(BaseEventObject):
    reacted_id: int
    peer_id: int
    cmid: int
    reaction_id: Optional[int] = None


class MessageReadObject(BaseEventObject):
    from_id: int
    peer_id: int
    read_message_id: int
    conversation_message_id: int


localns = locals().copy()
for item in localns.values():
    if not (isinstance(item, type) and issubclass(item, BaseEventObject)):
        continue

    item.model_rebuild(force=True, _types_namespace=localns)


__all__ = (
    "AudioNewObject",
    "AppPayloadObject",
    "BoardPostDeleteObject",
    "BoardPostEditObject",
    "BoardPostNewObject",
    "BoardPostRestoreObject",
    "ClientInfoForBots",
    "DonutMoneyWithdrawErrorObject",
    "DonutMoneyWithdrawObject",
    "DonutSubscriptionCancelledObject",
    "DonutSubscriptionCreateObject",
    "DonutSubscriptionExpiredObject",
    "DonutSubscriptionProlongedObject",
    "DonutSubscriptionPriceChangedObject",
    "GroupChangePhotoObject",
    "GroupChangeSettingsObject",
    "GroupLeaveObject",
    "GroupOfficersEditObject",
    "GroupSettingsChangesObject",
    "LeadFormsNewObject",
    "LikeAddObject",
    "LikeRemoveObject",
    "MarketCommentDeleteObject",
    "MarketCommentEditObject",
    "MarketCommentNewObject",
    "MarketCommentRestoreObject",
    "MarketOrderEditObject",
    "MarketOrderNewObject",
    "MessageAllowObject",
    "MessageDenyObject",
    "MessageEditObject",
    "MessageEventObject",
    "MessageNewObject",
    "MessageReplyObject",
    "MessageReactionEventObject",
    "MessageReadObject",
    "MessageTypingStateObject",
    "PhotoCommentDeleteObject",
    "PhotoCommentEditObject",
    "PhotoCommentNewObject",
    "PhotoCommentRestoreObject",
    "PhotoNewObject",
    "PollVoteNewObject",
    "UserBlockObject",
    "UserUnblockObject",
    "VideoCommentDeleteObject",
    "VideoCommentEditObject",
    "VideoCommentNewObject",
    "VideoCommentRestoreObject",
    "VideoNewObject",
    "WallPostNewObject",
    "WallReplyDeleteObject",
    "WallReplyEditObject",
    "WallReplyNewObject",
    "WallReplyRestoreObject",
    "WallRepostObject",
)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.adsweb import *  # noqa: F401,F403  # type: ignore


class AdswebCategory(BaseCategory):
    async def get_ad_categories(
        self,
        office_id: int,
        **kwargs: typing.Any,
    ) -> AdswebGetAdCategoriesResponseModel:
        """Method `adsweb.getAdCategories()`

        :param office_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("adsweb.getAdCategories", params)
        model = AdswebGetAdCategoriesResponse
        return model(**response).response

    async def get_ad_unit_code(
        self,
        **kwargs: typing.Any,
    ) -> AdswebGetAdUnitCodeResponseModel:
        """Method `adsweb.getAdUnitCode()`"""

        params = self.get_set_params(locals())
        response = await self.api.request("adsweb.getAdUnitCode", params)
        model = AdswebGetAdUnitCodeResponse
        return model(**response).response

    async def get_ad_units(
        self,
        office_id: int,
        ad_units_ids: typing.Optional[str] = None,
        fields: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        sites_ids: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> AdswebGetAdUnitsResponseModel:
        """Method `adsweb.getAdUnits()`

        :param office_id:
        :param ad_units_ids:
        :param fields:
        :param limit:
        :param offset:
        :param sites_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("adsweb.getAdUnits", params)
        model = AdswebGetAdUnitsResponse
        return model(**response).response

    async def get_fraud_history(
        self,
        office_id: int,
        limit: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        sites_ids: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> AdswebGetFraudHistoryResponseModel:
        """Method `adsweb.getFraudHistory()`

        :param office_id:
        :param limit:
        :param offset:
        :param sites_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("adsweb.getFraudHistory", params)
        model = AdswebGetFraudHistoryResponse
        return model(**response).response

    async def get_sites(
        self,
        office_id: int,
        fields: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        sites_ids: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> AdswebGetSitesResponseModel:
        """Method `adsweb.getSites()`

        :param office_id:
        :param fields:
        :param limit:
        :param offset:
        :param sites_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("adsweb.getSites", params)
        model = AdswebGetSitesResponse
        return model(**response).response

    async def get_statistics(
        self,
        date_from: str,
        date_to: str,
        ids: str,
        ids_type: str,
        office_id: int,
        period: str,
        fields: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        page_id: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> AdswebGetStatisticsResponseModel:
        """Method `adsweb.getStatistics()`

        :param date_from:
        :param date_to:
        :param ids:
        :param ids_type:
        :param office_id:
        :param period:
        :param fields:
        :param limit:
        :param page_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("adsweb.getStatistics", params)
        model = AdswebGetStatisticsResponse
        return model(**response).response


__all__ = ("AdswebCategory",)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import (
    SecureGiveEventStickerItem,
    SecureLevel,
    SecureSmsNotification,
    SecureTokenChecked,
    SecureTransaction,
)
from vkbottle_types.responses.base import (
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.base_response import DictResponse
from vkbottle_types.responses.secure import *  # noqa: F401,F403  # type: ignore


class SecureCategory(BaseCategory):
    async def add_app_event(
        self,
        activity_id: int,
        user_id: typing.Optional[int] = None,
        value: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `secure.addAppEvent()`

        :param activity_id: there are 2 default activities: , * 1 - level. Works similar to ,, * 2 - points, saves points amount, Any other value is for saving completed missions
        :param user_id: ID of a user to save the data
        :param value: depends on activity_id: * 1 - number, current level number,, * 2 - number, current user's points amount, , Any other value is ignored
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.addAppEvent", params)
        model = BaseOkResponse
        return model(**response).response

    async def check_token(
        self,
        ip: typing.Optional[str] = None,
        token: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> "SecureTokenChecked":
        """Method `secure.checkToken()`

        :param ip: user 'ip address'. Note that user may access using the 'ipv6' address, in this case it is required to transmit the 'ipv6' address. If not transmitted, the address will not be checked.
        :param token: client 'access_token'
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.checkToken", params)
        model = SecureCheckTokenResponse
        return model(**response).response

    async def get_app_balance(
        self,
        **kwargs: typing.Any,
    ) -> int:
        """Method `secure.getAppBalance()`"""

        params = self.get_set_params(locals())
        response = await self.api.request("secure.getAppBalance", params)
        model = SecureGetAppBalanceResponse
        return model(**response).response

    async def get_smshistory(
        self,
        date_from: typing.Optional[int] = None,
        date_to: typing.Optional[int] = None,
        limit: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.List[SecureSmsNotification]:
        """Method `secure.getSMSHistory()`

        :param date_from: filter by start date. It is set as UNIX-time.
        :param date_to: filter by end date. It is set as UNIX-time.
        :param limit: number of returned posts. By default - 1000.
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.getSMSHistory", params)
        model = SecureGetSMSHistoryResponse
        return model(**response).response

    async def get_transactions_history(
        self,
        date_from: typing.Optional[int] = None,
        date_to: typing.Optional[int] = None,
        limit: typing.Optional[int] = None,
        type: typing.Optional[int] = None,
        uid_from: typing.Optional[int] = None,
        uid_to: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.List[SecureTransaction]:
        """Method `secure.getTransactionsHistory()`

        :param date_from:
        :param date_to:
        :param limit:
        :param type:
        :param uid_from:
        :param uid_to:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.getTransactionsHistory", params)
        model = SecureGetTransactionsHistoryResponse
        return model(**response).response

    async def get_user_level(
        self,
        user_ids: typing.List[int],
        **kwargs: typing.Any,
    ) -> typing.List[SecureLevel]:
        """Method `secure.getUserLevel()`

        :param user_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.getUserLevel", params)
        model = SecureGetUserLevelResponse
        return model(**response).response

    async def give_event_sticker(
        self,
        achievement_id: int,
        user_ids: typing.List[int],
        **kwargs: typing.Any,
    ) -> typing.List[SecureGiveEventStickerItem]:
        """Method `secure.giveEventSticker()`

        :param achievement_id:
        :param user_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.giveEventSticker", params)
        model = SecureGiveEventStickerResponse
        return model(**response).response

    async def send_notification(
        self,
        message: str,
        notification_id: typing.Optional[int] = None,
        promo_id: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        user_ids: typing.Optional[typing.List[int]] = None,
        **kwargs: typing.Any,
    ) -> typing.List[int]:
        """Method `secure.sendNotification()`

        :param message: notification text which should be sent in 'UTF-8' encoding ('254' characters maximum).
        :param notification_id:
        :param promo_id:
        :param user_id:
        :param user_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.sendNotification", params)
        model = SecureSendNotificationResponse
        return model(**response).response

    async def send_smsnotification(
        self,
        message: str,
        user_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `secure.sendSMSNotification()`

        :param message: 'SMS' text to be sent in 'UTF-8' encoding. Only Latin letters and numbers are allowed. Maximum size is '160' characters.
        :param user_id: ID of the user to whom SMS notification is sent. The user shall allow the application to send him/her notifications (, +1).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.sendSMSNotification", params)
        model = BaseOkResponse
        return model(**response).response

    async def set_counter(
        self,
        counter: typing.Optional[int] = None,
        counters: typing.Optional[typing.List[str]] = None,
        increment: typing.Optional[bool] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.Dict[str, typing.Any]:
        """Method `secure.setCounter()`

        :param counter: counter value.
        :param counters:
        :param increment:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("secure.setCounter", params)
        model = DictResponse
        return model(**response).response


__all__ = ("SecureCategory",)



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import WidgetsWidgetComment, WidgetsWidgetPage
from vkbottle_types.responses.base_response import BaseResponse


class WidgetsGetCommentsResponseModel(BaseModel):
    count: int = Field()
    posts: typing.List["WidgetsWidgetComment"] = Field()


class WidgetsGetCommentsResponse(BaseResponse):
    response: "WidgetsGetCommentsResponseModel" = Field()


class WidgetsGetPagesResponseModel(BaseModel):
    count: int = Field()
    pages: typing.List["WidgetsWidgetPage"] = Field()


class WidgetsGetPagesResponse(BaseResponse):
    response: "WidgetsGetPagesResponseModel" = Field()



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    GroupsGroupFull,
    MessagesChat,
    MessagesChatFull,
    MessagesChatPreview,
    MessagesConversation,
    MessagesConversationWithMessage,
    MessagesDeleteFullResponseItem,
    MessagesGetConversationById,
    MessagesGetConversationByIdExtended,
    MessagesGetConversationMembers,
    MessagesGetInviteLinkByOwnerResponseItem,
    MessagesHistoryAttachment,
    MessagesLastActivity,
    MessagesLongpollMessages,
    MessagesLongpollParams,
    MessagesMessage,
    MessagesMessagesArray,
    MessagesPinnedMessage,
    MessagesReactionAssetItem,
    MessagesReactionCounterResponseItem,
    MessagesReactionCountersResponseItem,
    MessagesReactionResponseItem,
    MessagesSendUserIdsResponseItem,
    UsersUser,
    UsersUserFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class MessagesAddChatUsersResponseModel(BaseModel):
    failed_peer_ids: typing.List[int] = Field()
    failed_phone_numbers: typing.List[str] = Field()
    invitees: typing.List[int] = Field()


class MessagesAddChatUsersResponse(BaseResponse):
    response: "MessagesAddChatUsersResponseModel" = Field()


class MessagesCreateChatWithPeerIdsResponseModel(BaseModel):
    chat_id: typing.Optional[int] = Field(
        default=None,
    )
    peer_ids: typing.Optional[typing.List[int]] = Field(
        default=None,
    )


class MessagesCreateChatWithPeerIdsResponse(BaseResponse):
    response: "MessagesCreateChatWithPeerIdsResponseModel" = Field()


class MessagesDeleteChatPhotoResponseModel(BaseModel):
    message_id: typing.Optional[int] = Field(
        default=None,
    )
    chat: typing.Optional["MessagesChat"] = Field(
        default=None,
    )


class MessagesDeleteChatPhotoResponse(BaseResponse):
    response: "MessagesDeleteChatPhotoResponseModel" = Field()


class MessagesDeleteConversationResponseModel(BaseModel):
    last_deleted_id: int = Field()


class MessagesDeleteConversationResponse(BaseResponse):
    response: "MessagesDeleteConversationResponseModel" = Field()


class MessagesDeleteFullResponse(BaseResponse):
    response: typing.List["MessagesDeleteFullResponseItem"] = Field()


class MessagesGetByConversationMessageIdExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["MessagesMessage"] = Field()
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )


class MessagesGetByConversationMessageIdExtendedResponse(BaseResponse):
    response: "MessagesGetByConversationMessageIdExtendedResponseModel" = Field()


class MessagesGetByConversationMessageIdResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["MessagesMessage"] = Field()


class MessagesGetByConversationMessageIdResponse(BaseResponse):
    response: "MessagesGetByConversationMessageIdResponseModel" = Field()


class MessagesGetByIdExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["MessagesMessage"] = Field()
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )


class MessagesGetByIdExtendedResponse(BaseResponse):
    response: "MessagesGetByIdExtendedResponseModel" = Field()


class MessagesGetByIdResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["MessagesMessage"] = Field()


class MessagesGetByIdResponse(BaseResponse):
    response: "MessagesGetByIdResponseModel" = Field()


class MessagesGetChatPreviewResponseModel(BaseModel):
    preview: typing.Optional["MessagesChatPreview"] = Field(
        default=None,
    )
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )


class MessagesGetChatPreviewResponse(BaseResponse):
    response: "MessagesGetChatPreviewResponseModel" = Field()


class MessagesGetChatChatIdsFieldsResponse(BaseResponse):
    response: typing.List["MessagesChatFull"] = Field()


class MessagesGetChatChatIdsResponse(BaseResponse):
    response: typing.List["MessagesChat"] = Field()


class MessagesGetChatFieldsResponse(BaseResponse):
    response: "MessagesChatFull" = Field()


class MessagesGetChatResponse(BaseResponse):
    response: "MessagesChat" = Field()


class MessagesGetConversationMembersResponse(BaseResponse):
    response: "MessagesGetConversationMembers" = Field()


class MessagesGetConversationsByIdExtendedResponse(BaseResponse):
    response: "MessagesGetConversationByIdExtended" = Field()


class MessagesGetConversationsByIdResponse(BaseResponse):
    response: "MessagesGetConversationById" = Field()


class MessagesGetConversationsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["MessagesConversationWithMessage"] = Field()
    unread_count: typing.Optional[int] = Field(
        default=None,
    )
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )


class MessagesGetConversationsResponse(BaseResponse):
    response: "MessagesGetConversationsResponseModel" = Field()


class MessagesGetHistoryAttachmentsResponseModel(BaseModel):
    items: typing.List["MessagesHistoryAttachment"] = Field()
    next_from: typing.Optional[str] = Field(
        default=None,
    )
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )


class MessagesGetHistoryAttachmentsResponse(BaseResponse):
    response: "MessagesGetHistoryAttachmentsResponseModel" = Field()


class MessagesGetHistoryExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["MessagesMessage"] = Field()
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )
    conversations: typing.Optional[typing.List["MessagesConversation"]] = Field(
        default=None,
    )


class MessagesGetHistoryExtendedResponse(BaseResponse):
    response: "MessagesGetHistoryExtendedResponseModel" = Field()


class MessagesGetHistoryResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["MessagesMessage"] = Field()


class MessagesGetHistoryResponse(BaseResponse):
    response: "MessagesGetHistoryResponseModel" = Field()


class MessagesGetImportantMessagesExtendedResponseModel(BaseModel):
    messages: "MessagesMessagesArray" = Field()
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )
    conversations: typing.Optional[typing.List["MessagesConversation"]] = Field(
        default=None,
    )


class MessagesGetImportantMessagesExtendedResponse(BaseResponse):
    response: "MessagesGetImportantMessagesExtendedResponseModel" = Field()


class MessagesGetImportantMessagesResponseModel(BaseModel):
    messages: "MessagesMessagesArray" = Field()
    profiles: typing.Optional[typing.List["UsersUser"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )
    conversations: typing.Optional[typing.List["MessagesConversation"]] = Field(
        default=None,
    )


class MessagesGetImportantMessagesResponse(BaseResponse):
    response: "MessagesGetImportantMessagesResponseModel" = Field()


class MessagesGetIntentUsersResponseModel(BaseModel):
    count: int = Field()
    items: typing.List[int] = Field()
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )


class MessagesGetIntentUsersResponse(BaseResponse):
    response: "MessagesGetIntentUsersResponseModel" = Field()


class MessagesGetInviteLinkByOwnerResponseModel(BaseModel):
    items: typing.List["MessagesGetInviteLinkByOwnerResponseItem"] = Field()


class MessagesGetInviteLinkByOwnerResponse(BaseResponse):
    response: "MessagesGetInviteLinkByOwnerResponseModel" = Field()


class MessagesGetInviteLinkResponseModel(BaseModel):
    link: typing.Optional[str] = Field(
        default=None,
    )


class MessagesGetInviteLinkResponse(BaseResponse):
    response: "MessagesGetInviteLinkResponseModel" = Field()


class MessagesGetLastActivityResponse(BaseResponse):
    response: "MessagesLastActivity" = Field()


class MessagesGetLongPollHistoryResponseModel(BaseModel):
    history: typing.Optional[typing.List[typing.List[typing.Union["str", "int"]]]] = Field(
        default=None,
    )
    messages: typing.Optional["MessagesLongpollMessages"] = Field(
        default=None,
    )
    credentials: typing.Optional["MessagesLongpollParams"] = Field(
        default=None,
    )
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )
    chats: typing.Optional[typing.List["MessagesChat"]] = Field(
        default=None,
    )
    new_pts: typing.Optional[int] = Field(
        default=None,
    )
    from_pts: typing.Optional[int] = Field(
        default=None,
    )
    more: typing.Optional[bool] = Field(
        default=None,
    )
    conversations: typing.Optional[typing.List["MessagesConversation"]] = Field(
        default=None,
    )


class MessagesGetLongPollHistoryResponse(BaseResponse):
    response: "MessagesGetLongPollHistoryResponseModel" = Field()


class MessagesGetLongPollServerResponse(BaseResponse):
    response: "MessagesLongpollParams" = Field()


class MessagesGetMessagesReactionsResponseModel(BaseModel):
    items: typing.List["MessagesReactionCountersResponseItem"] = Field()
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )


class MessagesGetMessagesReactionsResponse(BaseResponse):
    response: "MessagesGetMessagesReactionsResponseModel" = Field()


class MessagesGetReactedPeersResponseModel(BaseModel):
    count: int = Field()
    reactions: typing.List["MessagesReactionResponseItem"] = Field()
    counters: typing.List["MessagesReactionCounterResponseItem"] = Field()
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )


class MessagesGetReactedPeersResponse(BaseResponse):
    response: "MessagesGetReactedPeersResponseModel" = Field()


class MessagesGetReactionsAssetsResponseModel(BaseModel):
    version: int = Field()
    assets: typing.List["MessagesReactionAssetItem"] = Field()
    override_assets: typing.Optional[typing.List["MessagesReactionAssetItem"]] = Field(
        default=None,
    )


class MessagesGetReactionsAssetsResponse(BaseResponse):
    response: "MessagesGetReactionsAssetsResponseModel" = Field()


class MessagesIsMessagesFromGroupAllowedResponseModel(BaseModel):
    is_allowed: typing.Optional[bool] = Field(
        default=None,
    )


class MessagesIsMessagesFromGroupAllowedResponse(BaseResponse):
    response: "MessagesIsMessagesFromGroupAllowedResponseModel" = Field()


class MessagesJoinChatByInviteLinkResponseModel(BaseModel):
    chat_id: typing.Optional[int] = Field(
        default=None,
    )


class MessagesJoinChatByInviteLinkResponse(BaseResponse):
    response: "MessagesJoinChatByInviteLinkResponseModel" = Field()


class MessagesMarkAsImportantDeprecatedResponse(BaseResponse):
    response: typing.List[int] = Field()


class MessagesPinResponse(BaseResponse):
    response: "MessagesPinnedMessage" = Field()


class MessagesSearchConversationsExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["MessagesConversation"] = Field()
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )


class MessagesSearchConversationsExtendedResponse(BaseResponse):
    response: "MessagesSearchConversationsExtendedResponseModel" = Field()


class MessagesSearchConversationsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["MessagesConversation"] = Field()


class MessagesSearchConversationsResponse(BaseResponse):
    response: "MessagesSearchConversationsResponseModel" = Field()


class MessagesSearchExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["MessagesMessage"] = Field()
    profiles: typing.Optional[typing.List["UsersUserFull"]] = Field(
        default=None,
    )
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )
    conversations: typing.Optional[typing.List["MessagesConversation"]] = Field(
        default=None,
    )


class MessagesSearchExtendedResponse(BaseResponse):
    response: "MessagesSearchExtendedResponseModel" = Field()


class MessagesSearchResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["MessagesMessage"] = Field()


class MessagesSearchResponse(BaseResponse):
    response: "MessagesSearchResponseModel" = Field()


class MessagesSendDeprecatedResponse(BaseResponse):
    response: int = Field()


class MessagesSendUserIdsResponse(BaseResponse):
    response: typing.List["MessagesSendUserIdsResponseItem"] = Field()


class MessagesSetChatPhotoResponseModel(BaseModel):
    message_id: typing.Optional[int] = Field(
        default=None,
    )
    chat: typing.Optional["MessagesChat"] = Field(
        default=None,
    )


class MessagesSetChatPhotoResponse(BaseResponse):
    response: "MessagesSetChatPhotoResponseModel" = Field()



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import BaseUploadServer, UsersFields
from vkbottle_types.responses.base import (
    BaseBoolResponse,
    BaseGetUploadServerResponse,
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.market import *  # noqa: F401,F403  # type: ignore


class MarketCategory(BaseCategory):
    async def add(
        self,
        category_id: int,
        description: str,
        name: str,
        owner_id: int,
        deleted: typing.Optional[bool] = None,
        dimension_height: typing.Optional[int] = None,
        dimension_length: typing.Optional[int] = None,
        dimension_width: typing.Optional[int] = None,
        is_main_variant: typing.Optional[bool] = None,
        main_photo_id: typing.Optional[int] = None,
        old_price: typing.Optional[float] = None,
        photo_ids: typing.Optional[typing.List[int]] = None,
        price: typing.Optional[float] = None,
        sku: typing.Optional[str] = None,
        stock_amount: typing.Optional[int] = None,
        url: typing.Optional[str] = None,
        variant_ids: typing.Optional[typing.List[int]] = None,
        video_ids: typing.Optional[typing.List[int]] = None,
        weight: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> MarketAddResponseModel:
        """Method `market.add()`

        :param category_id: Item category ID.
        :param description: Item description.
        :param name: Item name.
        :param owner_id: ID of an item owner community.
        :param deleted: Item status ('1' - deleted, '0' - not deleted).
        :param dimension_height:
        :param dimension_length:
        :param dimension_width:
        :param is_main_variant: Is main in their group.
        :param main_photo_id: Cover photo ID.
        :param old_price:
        :param photo_ids: IDs of additional photos.
        :param price: Item price.
        :param sku:
        :param stock_amount:
        :param url: Url for button in market item.
        :param variant_ids: IDs of properties variants.
        :param video_ids: IDs of additional videos.
        :param weight:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.add", params)
        model = MarketAddResponse
        return model(**response).response

    async def add_album(
        self,
        owner_id: int,
        title: str,
        is_hidden: typing.Optional[bool] = None,
        main_album: typing.Optional[bool] = None,
        photo_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> MarketAddAlbumResponseModel:
        """Method `market.addAlbum()`

        :param owner_id: ID of an item owner community.
        :param title: Collection title.
        :param is_hidden: Set as hidden
        :param main_album: Set as main ('1' - set, '0' - no).
        :param photo_id: Cover photo ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.addAlbum", params)
        model = MarketAddAlbumResponse
        return model(**response).response

    async def add_property(
        self,
        group_id: int,
        title: str,
        **kwargs: typing.Any,
    ) -> MarketAddPropertyResponseModel:
        """Method `market.addProperty()`

        :param group_id: Group id.
        :param title: Property name.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.addProperty", params)
        model = MarketAddPropertyResponse
        return model(**response).response

    async def add_property_variant(
        self,
        group_id: int,
        property_id: int,
        title: str,
        **kwargs: typing.Any,
    ) -> MarketAddPropertyVariantResponseModel:
        """Method `market.addPropertyVariant()`

        :param group_id: Group id.
        :param property_id: Property id.
        :param title: Variant name.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.addPropertyVariant", params)
        model = MarketAddPropertyVariantResponse
        return model(**response).response

    async def add_to_album(
        self,
        album_ids: typing.List[int],
        item_ids: typing.List[int],
        owner_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.addToAlbum()`

        :param album_ids: Collections IDs to add item to.
        :param item_ids:
        :param owner_id: ID of an item owner community.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.addToAlbum", params)
        model = BaseOkResponse
        return model(**response).response

    async def create_comment(
        self,
        item_id: int,
        owner_id: int,
        attachments: typing.Optional[typing.List[str]] = None,
        from_group: typing.Optional[bool] = None,
        guid: typing.Optional[str] = None,
        message: typing.Optional[str] = None,
        reply_to_comment: typing.Optional[int] = None,
        sticker_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `market.createComment()`

        :param item_id: Item ID.
        :param owner_id: ID of an item owner community.
        :param attachments: Comma-separated list of objects attached to a comment. The field is submitted the following way: , "'<owner_id>_<media_id>,<owner_id>_<media_id>'", , '' - media attachment type: "'photo' - photo, 'video' - video, 'audio' - audio, 'doc' - document", , '<owner_id>' - media owner id, '<media_id>' - media attachment id, , For example: "photo100172_166443618,photo66748_265827614",
        :param from_group: '1' - comment will be published on behalf of a community, '0' - on behalf of a user (by default).
        :param guid: Random value to avoid resending one comment.
        :param message: Comment text (required if 'attachments' parameter is not specified)
        :param reply_to_comment: ID of a comment to reply with current comment to.
        :param sticker_id: Sticker ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.createComment", params)
        model = MarketCreateCommentResponse
        return model(**response).response

    async def delete(
        self,
        item_id: int,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.delete()`

        :param item_id: Item ID.
        :param owner_id: ID of an item owner community.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.delete", params)
        model = BaseOkResponse
        return model(**response).response

    async def delete_album(
        self,
        album_id: int,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.deleteAlbum()`

        :param album_id: Collection ID.
        :param owner_id: ID of an collection owner community.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.deleteAlbum", params)
        model = BaseOkResponse
        return model(**response).response

    async def delete_comment(
        self,
        comment_id: int,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `market.deleteComment()`

        :param comment_id: comment id
        :param owner_id: identifier of an item owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.deleteComment", params)
        model = BaseBoolResponse
        return model(**response).response

    async def delete_property(
        self,
        group_id: int,
        property_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.deleteProperty()`

        :param group_id: Group id.
        :param property_id: Property id.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.deleteProperty", params)
        model = BaseOkResponse
        return model(**response).response

    async def delete_property_variant(
        self,
        group_id: int,
        variant_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.deletePropertyVariant()`

        :param group_id: Group id.
        :param variant_id: Variant id.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.deletePropertyVariant", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit(
        self,
        item_id: int,
        owner_id: int,
        category_id: typing.Optional[int] = None,
        deleted: typing.Optional[bool] = None,
        description: typing.Optional[str] = None,
        dimension_height: typing.Optional[int] = None,
        dimension_length: typing.Optional[int] = None,
        dimension_width: typing.Optional[int] = None,
        is_main_variant: typing.Optional[bool] = None,
        main_photo_id: typing.Optional[int] = None,
        name: typing.Optional[str] = None,
        old_price: typing.Optional[float] = None,
        photo_ids: typing.Optional[typing.List[int]] = None,
        price: typing.Optional[float] = None,
        sku: typing.Optional[str] = None,
        stock_amount: typing.Optional[int] = None,
        url: typing.Optional[str] = None,
        variant_ids: typing.Optional[typing.List[int]] = None,
        video_ids: typing.Optional[typing.List[int]] = None,
        weight: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.edit()`

        :param item_id: Item ID.
        :param owner_id: ID of an item owner community.
        :param category_id: Item category ID.
        :param deleted: Item status ('1' - deleted, '0' - not deleted).
        :param description: Item description.
        :param dimension_height:
        :param dimension_length:
        :param dimension_width:
        :param is_main_variant: Is main in their group.
        :param main_photo_id: Cover photo ID.
        :param name: Item name.
        :param old_price:
        :param photo_ids: IDs of additional photos.
        :param price: Item price.
        :param sku:
        :param stock_amount:
        :param url: Url for button in market item.
        :param variant_ids: IDs of properties variants.
        :param video_ids: IDs of additional videos.
        :param weight:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.edit", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit_album(
        self,
        album_id: int,
        owner_id: int,
        title: str,
        is_hidden: typing.Optional[bool] = None,
        main_album: typing.Optional[bool] = None,
        photo_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.editAlbum()`

        :param album_id: Collection ID.
        :param owner_id: ID of an collection owner community.
        :param title: Collection title.
        :param is_hidden: Set as hidden
        :param main_album: Set as main ('1' - set, '0' - no).
        :param photo_id: Cover photo id
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.editAlbum", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit_comment(
        self,
        comment_id: int,
        owner_id: int,
        attachments: typing.Optional[typing.List[str]] = None,
        message: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.editComment()`

        :param comment_id: Comment ID.
        :param owner_id: ID of an item owner community.
        :param attachments: Comma-separated list of objects attached to a comment. The field is submitted the following way: , "'<owner_id>_<media_id>,<owner_id>_<media_id>'", , '' - media attachment type: "'photo' - photo, 'video' - video, 'audio' - audio, 'doc' - document", , '<owner_id>' - media owner id, '<media_id>' - media attachment id, , For example: "photo100172_166443618,photo66748_265827614",
        :param message: New comment text (required if 'attachments' are not specified), , 2048 symbols maximum.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.editComment", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit_order(
        self,
        order_id: int,
        user_id: int,
        comment_for_user: typing.Optional[str] = None,
        delivery_price: typing.Optional[int] = None,
        height: typing.Optional[int] = None,
        length: typing.Optional[int] = None,
        merchant_comment: typing.Optional[str] = None,
        payment_status: typing.Optional[str] = None,
        receipt_link: typing.Optional[str] = None,
        status: typing.Optional[int] = None,
        track_number: typing.Optional[str] = None,
        weight: typing.Optional[int] = None,
        width: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.editOrder()`

        :param order_id:
        :param user_id:
        :param comment_for_user:
        :param delivery_price:
        :param height:
        :param length:
        :param merchant_comment:
        :param payment_status:
        :param receipt_link:
        :param status:
        :param track_number:
        :param weight:
        :param width:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.editOrder", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit_property(
        self,
        group_id: int,
        property_id: int,
        title: str,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.editProperty()`

        :param group_id: Group id.
        :param property_id: Property id.
        :param title: Property name
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.editProperty", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit_property_variant(
        self,
        group_id: int,
        title: str,
        variant_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.editPropertyVariant()`

        :param group_id: Group id.
        :param title: Variant name.
        :param variant_id: Variant id.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.editPropertyVariant", params)
        model = BaseOkResponse
        return model(**response).response

    async def filter_categories(
        self,
        category_id: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        query: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> MarketGetCategoriesNewResponseModel:
        """Method `market.filterCategories()`

        :param category_id: Category_id filter categories
        :param count: Number of results to return.
        :param query: Query filter categories
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.filterCategories", params)
        model = MarketGetCategoriesNewResponse
        return model(**response).response

    @typing.overload
    async def get(
        self,
        owner_id: int,
        extended: typing.Literal[True],
        album_id: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        date_from: typing.Optional[str] = None,
        date_to: typing.Optional[str] = None,
        fields: typing.Optional[typing.List[str]] = None,
        need_variants: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        with_disabled: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> MarketGetExtendedResponseModel: ...

    @typing.overload
    async def get(
        self,
        owner_id: int,
        extended: typing.Optional[typing.Literal[False]] = None,
        album_id: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        date_from: typing.Optional[str] = None,
        date_to: typing.Optional[str] = None,
        fields: typing.Optional[typing.List[str]] = None,
        need_variants: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        with_disabled: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> MarketGetResponseModel: ...

    async def get(
        self,
        owner_id: int,
        extended: typing.Optional[bool] = None,
        album_id: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        date_from: typing.Optional[str] = None,
        date_to: typing.Optional[str] = None,
        fields: typing.Optional[typing.List[str]] = None,
        need_variants: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        with_disabled: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> typing.Union[MarketGetResponseModel, MarketGetExtendedResponseModel]:
        """Method `market.get()`

        :param owner_id: ID of an item owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
        :param extended: '1' - method will return additional fields: 'likes, can_comment, car_repost, photos'. These parameters are not returned by default.
        :param album_id:
        :param count: Number of items to return.
        :param date_from: Items update date from (format: yyyy-mm-dd)
        :param date_to: Items update date to (format: yyyy-mm-dd)
        :param fields:
        :param need_variants: Add variants to response if exist
        :param offset: Offset needed to return a specific subset of results.
        :param with_disabled: Add disabled items to response
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.get", params)
        model = self.get_model(
            ((("extended",), MarketGetExtendedResponse),),
            default=MarketGetResponse,
            params=params,
        )
        return model(**response).response

    async def get_album_by_id(
        self,
        album_ids: typing.List[int],
        owner_id: int,
        **kwargs: typing.Any,
    ) -> MarketGetAlbumByIdResponseModel:
        """Method `market.getAlbumById()`

        :param album_ids: collections identifiers to obtain data from
        :param owner_id: identifier of an album owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getAlbumById", params)
        model = MarketGetAlbumByIdResponse
        return model(**response).response

    async def get_albums(
        self,
        owner_id: int,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> MarketGetAlbumsResponseModel:
        """Method `market.getAlbums()`

        :param owner_id: ID of an items owner community.
        :param count: Number of items to return.
        :param offset: Offset needed to return a specific subset of results.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getAlbums", params)
        model = MarketGetAlbumsResponse
        return model(**response).response

    @typing.overload
    async def get_by_id(
        self,
        item_ids: typing.List[str],
        extended: typing.Literal[True],
        **kwargs: typing.Any,
    ) -> MarketGetByIdExtendedResponseModel: ...

    @typing.overload
    async def get_by_id(
        self,
        item_ids: typing.List[str],
        extended: typing.Optional[typing.Literal[False]] = None,
        **kwargs: typing.Any,
    ) -> MarketGetByIdResponseModel: ...

    async def get_by_id(
        self,
        item_ids: typing.List[str],
        extended: typing.Optional[bool] = None,
        **kwargs: typing.Any,
    ) -> typing.Union[MarketGetByIdResponseModel, MarketGetByIdExtendedResponseModel]:
        """Method `market.getById()`

        :param item_ids: Comma-separated ids list: {user id}_{item id}. If an item belongs to a community -{community id} is used. " 'Videos' value example: , '-4363_136089719,13245770_137352259'"
        :param extended: '1' - to return additional fields: 'likes, can_comment, car_repost, photos'. By default: '0'.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getById", params)
        model = self.get_model(
            ((("extended",), MarketGetByIdExtendedResponse),),
            default=MarketGetByIdResponse,
            params=params,
        )
        return model(**response).response

    async def get_categories(
        self,
        album_id: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> MarketGetCategoriesNewResponseModel:
        """Method `market.getCategories()`

        :param album_id:
        :param group_id: Group Id.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getCategories", params)
        model = MarketGetCategoriesNewResponse
        return model(**response).response

    async def get_comments(
        self,
        item_id: int,
        owner_id: int,
        count: typing.Optional[int] = None,
        extended: typing.Optional[bool] = None,
        fields: typing.Optional[typing.List[UsersFields]] = None,
        need_likes: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        sort: typing.Optional[str] = None,
        start_comment_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> MarketGetCommentsResponseModel:
        """Method `market.getComments()`

        :param item_id: Item ID.
        :param owner_id: ID of an item owner community
        :param count: Number of results to return.
        :param extended: '1' - comments will be returned as numbered objects, in addition lists of 'profiles' and 'groups' objects will be returned.
        :param fields: List of additional profile fields to return. See the [vk.com/dev/fields|details]
        :param need_likes: '1' - to return likes info.
        :param offset:
        :param sort: Sort order ('asc' - from old to new, 'desc' - from new to old)
        :param start_comment_id: ID of a comment to start a list from (details below).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getComments", params)
        model = MarketGetCommentsResponse
        return model(**response).response

    async def get_group_orders(
        self,
        count: typing.Optional[int] = None,
        group_id: typing.Optional[typing.Union["int", "str"]] = None,
        offset: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> MarketGetGroupOrdersResponseModel:
        """Method `market.getGroupOrders()`

        :param count:
        :param group_id: ID or groups domain
        :param offset:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getGroupOrders", params)
        model = MarketGetGroupOrdersResponse
        return model(**response).response

    async def get_order_by_id(
        self,
        order_id: int,
        extended: typing.Optional[bool] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> MarketGetOrderByIdResponseModel:
        """Method `market.getOrderById()`

        :param order_id:
        :param extended:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getOrderById", params)
        model = MarketGetOrderByIdResponse
        return model(**response).response

    async def get_order_items(
        self,
        order_id: int,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> MarketGetOrderItemsResponseModel:
        """Method `market.getOrderItems()`

        :param order_id:
        :param count:
        :param offset:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getOrderItems", params)
        model = MarketGetOrderItemsResponse
        return model(**response).response

    @typing.overload
    async def get_orders(
        self,
        extended: typing.Literal[True],
        count: typing.Optional[int] = None,
        date_from: typing.Optional[str] = None,
        date_to: typing.Optional[str] = None,
        offset: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> MarketGetOrdersExtendedResponseModel: ...

    @typing.overload
    async def get_orders(
        self,
        extended: typing.Optional[typing.Literal[False]] = None,
        count: typing.Optional[int] = None,
        date_from: typing.Optional[str] = None,
        date_to: typing.Optional[str] = None,
        offset: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> MarketGetOrdersResponseModel: ...

    async def get_orders(
        self,
        extended: typing.Optional[bool] = None,
        count: typing.Optional[int] = None,
        date_from: typing.Optional[str] = None,
        date_to: typing.Optional[str] = None,
        offset: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.Union[MarketGetOrdersResponseModel, MarketGetOrdersExtendedResponseModel]:
        """Method `market.getOrders()`

        :param extended:
        :param count:
        :param date_from: Orders status updated date from (format: yyyy-mm-dd)
        :param date_to: Orders status updated date to (format: yyyy-mm-dd)
        :param offset:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getOrders", params)
        model = self.get_model(
            ((("extended",), MarketGetOrdersExtendedResponse),),
            default=MarketGetOrdersResponse,
            params=params,
        )
        return model(**response).response

    async def get_product_photo_upload_server(
        self,
        group_id: int,
        **kwargs: typing.Any,
    ) -> "BaseUploadServer":
        """Method `market.getProductPhotoUploadServer()`

        :param group_id: Community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getProductPhotoUploadServer", params)
        model = BaseGetUploadServerResponse
        return model(**response).response

    async def get_properties(
        self,
        group_id: int,
        **kwargs: typing.Any,
    ) -> MarketGetPropertiesResponseModel:
        """Method `market.getProperties()`

        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.getProperties", params)
        model = MarketGetPropertiesResponse
        return model(**response).response

    async def group_items(
        self,
        group_id: int,
        item_ids: typing.List[int],
        item_group_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> MarketGroupItemsResponseModel:
        """Method `market.groupItems()`

        :param group_id: Group id.
        :param item_ids: Item ids.
        :param item_group_id: Items group id.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.groupItems", params)
        model = MarketGroupItemsResponse
        return model(**response).response

    async def remove_from_album(
        self,
        album_ids: typing.List[int],
        item_id: int,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.removeFromAlbum()`

        :param album_ids: Collections IDs to remove item from.
        :param item_id: Item ID.
        :param owner_id: ID of an item owner community.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.removeFromAlbum", params)
        model = BaseOkResponse
        return model(**response).response

    async def reorder_albums(
        self,
        album_id: int,
        owner_id: int,
        after: typing.Optional[int] = None,
        before: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.reorderAlbums()`

        :param album_id: Collection ID.
        :param owner_id: ID of an item owner community.
        :param after: ID of a collection to place current collection after it.
        :param before: ID of a collection to place current collection before it.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.reorderAlbums", params)
        model = BaseOkResponse
        return model(**response).response

    async def reorder_items(
        self,
        item_id: int,
        owner_id: int,
        after: typing.Optional[int] = None,
        album_id: typing.Optional[int] = None,
        before: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.reorderItems()`

        :param item_id: Item ID.
        :param owner_id: ID of an item owner community.
        :param after: ID of an item to place current item after it.
        :param album_id: ID of a collection to reorder items in. Set 0 to reorder full items list.
        :param before: ID of an item to place current item before it.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.reorderItems", params)
        model = BaseOkResponse
        return model(**response).response

    async def report(
        self,
        item_id: int,
        owner_id: int,
        reason: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.report()`

        :param item_id: Item ID.
        :param owner_id: ID of an item owner community.
        :param reason: Complaint reason. Possible values: *'0' - spam,, *'1' - child porn,, *'2' - extremism,, *'3' - violence,, *'4' - drugs propaganda,, *'5' - adult materials,, *'6' - insult.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.report", params)
        model = BaseOkResponse
        return model(**response).response

    async def report_comment(
        self,
        comment_id: int,
        owner_id: int,
        reason: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.reportComment()`

        :param comment_id: Comment ID.
        :param owner_id: ID of an item owner community.
        :param reason: Complaint reason. Possible values: *'0' - spam,, *'1' - child porn,, *'2' - extremism,, *'3' - violence,, *'4' - drugs propaganda,, *'5' - adult materials,, *'6' - insult.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.reportComment", params)
        model = BaseOkResponse
        return model(**response).response

    async def restore(
        self,
        item_id: int,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.restore()`

        :param item_id: Deleted item ID.
        :param owner_id: ID of an item owner community.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.restore", params)
        model = BaseOkResponse
        return model(**response).response

    async def restore_comment(
        self,
        comment_id: int,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `market.restoreComment()`

        :param comment_id: deleted comment id
        :param owner_id: identifier of an item owner community, "Note that community id in the 'owner_id' parameter should be negative number. For example 'owner_id'=-1 matches the [vk.com/apiclub|VK API] community "
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.restoreComment", params)
        model = BaseBoolResponse
        return model(**response).response

    async def save_product_photo(
        self,
        upload_response: str,
        **kwargs: typing.Any,
    ) -> MarketPhotoIdResponseModel:
        """Method `market.saveProductPhoto()`

        :param upload_response: Upload response
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.saveProductPhoto", params)
        model = MarketPhotoIdResponse
        return model(**response).response

    @typing.overload
    async def search(
        self,
        owner_id: int,
        extended: typing.Literal[True],
        album_id: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        need_variants: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        price_from: typing.Optional[int] = None,
        price_to: typing.Optional[int] = None,
        q: typing.Optional[str] = None,
        rev: typing.Optional[int] = None,
        sort: typing.Optional[int] = None,
        status: typing.Optional[typing.List[int]] = None,
        **kwargs: typing.Any,
    ) -> MarketSearchExtendedResponseModel: ...

    @typing.overload
    async def search(
        self,
        owner_id: int,
        extended: typing.Optional[typing.Literal[False]] = None,
        album_id: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        need_variants: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        price_from: typing.Optional[int] = None,
        price_to: typing.Optional[int] = None,
        q: typing.Optional[str] = None,
        rev: typing.Optional[int] = None,
        sort: typing.Optional[int] = None,
        status: typing.Optional[typing.List[int]] = None,
        **kwargs: typing.Any,
    ) -> MarketSearchResponseModel: ...

    async def search(
        self,
        owner_id: int,
        extended: typing.Optional[bool] = None,
        album_id: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        need_variants: typing.Optional[bool] = None,
        offset: typing.Optional[int] = None,
        price_from: typing.Optional[int] = None,
        price_to: typing.Optional[int] = None,
        q: typing.Optional[str] = None,
        rev: typing.Optional[int] = None,
        sort: typing.Optional[int] = None,
        status: typing.Optional[typing.List[int]] = None,
        **kwargs: typing.Any,
    ) -> typing.Union[MarketSearchResponseModel, MarketSearchExtendedResponseModel]:
        """Method `market.search()`

        :param owner_id: ID of an items owner community.
        :param extended: '1' - to return additional fields: 'likes, can_comment, car_repost, photos'. By default: '0'.
        :param album_id:
        :param count: Number of items to return.
        :param need_variants: Add variants to response if exist
        :param offset: Offset needed to return a specific subset of results.
        :param price_from: Minimum item price value.
        :param price_to: Maximum item price value.
        :param q: Search query, for example "pink slippers".
        :param rev: '0' - do not use reverse order, '1' - use reverse order
        :param sort:
        :param status:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.search", params)
        model = self.get_model(
            ((("extended",), MarketSearchExtendedResponse),),
            default=MarketSearchResponse,
            params=params,
        )
        return model(**response).response

    async def search_items(
        self,
        q: str,
        category_id: typing.Optional[int] = None,
        city: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        country: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        price_from: typing.Optional[int] = None,
        price_to: typing.Optional[int] = None,
        sort_by: typing.Optional[int] = None,
        sort_direction: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> MarketSearchResponseModel:
        """Method `market.searchItems()`

        :param q:
        :param category_id:
        :param city:
        :param count:
        :param country:
        :param offset:
        :param price_from:
        :param price_to:
        :param sort_by:
        :param sort_direction:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.searchItems", params)
        model = MarketSearchResponse
        return model(**response).response

    async def search_items_basic(
        self,
        q: str,
        category_id: typing.Optional[int] = None,
        city: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        country: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        only_my_groups: typing.Optional[bool] = None,
        price_from: typing.Optional[int] = None,
        price_to: typing.Optional[int] = None,
        sort_by: typing.Optional[int] = None,
        sort_direction: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> MarketSearchBasicResponseModel:
        """Method `market.searchItemsBasic()`

        :param q:
        :param category_id:
        :param city:
        :param count:
        :param country:
        :param offset:
        :param only_my_groups:
        :param price_from:
        :param price_to:
        :param sort_by:
        :param sort_direction:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.searchItemsBasic", params)
        model = MarketSearchBasicResponse
        return model(**response).response

    async def ungroup_items(
        self,
        group_id: int,
        item_group_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `market.ungroupItems()`

        :param group_id: Group id.
        :param item_group_id: Items group id.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("market.ungroupItems", params)
        model = BaseOkResponse
        return model(**response).response


__all__ = ("MarketCategory",)



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    GroupsGroupFull,
    UsersUser,
    UsersUserFull,
    WallWallComment,
    WallWallItem,
    WallWallpostAttachment,
    WallWallpostFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class WallCreateCommentResponseModel(BaseModel):
    comment_id: int = Field()
    parents_stack: typing.Optional[typing.List[int]] = Field(
        default=None,
    )


class WallCreateCommentResponse(BaseResponse):
    response: "WallCreateCommentResponseModel" = Field()


class WallEditResponseModel(BaseModel):
    post_id: int = Field()


class WallEditResponse(BaseResponse):
    response: "WallEditResponseModel" = Field()


class WallGetByIdExtendedResponseModel(BaseModel):
    items: typing.List["WallWallItem"] = Field()
    profiles: typing.List["UsersUserFull"] = Field()
    groups: typing.List["GroupsGroupFull"] = Field()


class WallGetByIdExtendedResponse(BaseResponse):
    response: "WallGetByIdExtendedResponseModel" = Field()


class WallGetByIdResponseModel(BaseModel):
    items: typing.Optional[typing.List["WallWallItem"]] = Field(
        default=None,
    )


class WallGetByIdResponse(BaseResponse):
    response: "WallGetByIdResponseModel" = Field()


class WallGetCommentExtendedResponseModel(BaseModel):
    items: typing.List["WallWallComment"] = Field()
    profiles: typing.List["UsersUserFull"] = Field()
    groups: typing.List["GroupsGroupFull"] = Field()
    can_post: typing.Optional[bool] = Field(
        default=None,
    )
    show_reply_button: typing.Optional[bool] = Field(
        default=None,
    )
    groups_can_post: typing.Optional[bool] = Field(
        default=None,
    )
    post_author_id: typing.Optional[int] = Field(
        default=None,
    )


class WallGetCommentExtendedResponse(BaseResponse):
    response: "WallGetCommentExtendedResponseModel" = Field()


class WallGetCommentResponseModel(BaseModel):
    items: typing.List["WallWallComment"] = Field()
    can_post: typing.Optional[bool] = Field(
        default=None,
    )
    show_reply_button: typing.Optional[bool] = Field(
        default=None,
    )
    groups_can_post: typing.Optional[bool] = Field(
        default=None,
    )


class WallGetCommentResponse(BaseResponse):
    response: "WallGetCommentResponseModel" = Field()


class WallGetCommentsExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["WallWallComment"] = Field()
    profiles: typing.List["UsersUserFull"] = Field()
    groups: typing.List["GroupsGroupFull"] = Field()
    current_level_count: typing.Optional[int] = Field(
        default=None,
    )
    can_post: typing.Optional[bool] = Field(
        default=None,
    )
    show_reply_button: typing.Optional[bool] = Field(
        default=None,
    )
    groups_can_post: typing.Optional[bool] = Field(
        default=None,
    )
    post_author_id: typing.Optional[int] = Field(
        default=None,
    )


class WallGetCommentsExtendedResponse(BaseResponse):
    response: "WallGetCommentsExtendedResponseModel" = Field()


class WallGetCommentsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["WallWallComment"] = Field()
    current_level_count: typing.Optional[int] = Field(
        default=None,
    )
    can_post: typing.Optional[bool] = Field(
        default=None,
    )
    show_reply_button: typing.Optional[bool] = Field(
        default=None,
    )
    groups_can_post: typing.Optional[bool] = Field(
        default=None,
    )


class WallGetCommentsResponse(BaseResponse):
    response: "WallGetCommentsResponseModel" = Field()


class WallGetRepostsResponseModel(BaseModel):
    items: typing.List["WallWallpostFull"] = Field()
    profiles: typing.List["UsersUserFull"] = Field()
    groups: typing.List["GroupsGroupFull"] = Field()


class WallGetRepostsResponse(BaseResponse):
    response: "WallGetRepostsResponseModel" = Field()


class WallGetExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["WallWallItem"] = Field()
    profiles: typing.List["UsersUserFull"] = Field()
    groups: typing.List["GroupsGroupFull"] = Field()


class WallGetExtendedResponse(BaseResponse):
    response: "WallGetExtendedResponseModel" = Field()


class WallGetResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["WallWallItem"] = Field()


class WallGetResponse(BaseResponse):
    response: "WallGetResponseModel" = Field()


class WallParseAttachedLinkResponseModel(BaseModel):
    data: typing.List["WallWallpostAttachment"] = Field()
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = Field(
        default=None,
    )
    profiles: typing.Optional[typing.List["UsersUser"]] = Field(
        default=None,
    )


class WallParseAttachedLinkResponse(BaseResponse):
    response: "WallParseAttachedLinkResponseModel" = Field()


class WallPostAdsStealthResponseModel(BaseModel):
    post_id: int = Field()


class WallPostAdsStealthResponse(BaseResponse):
    response: "WallPostAdsStealthResponseModel" = Field()


class WallPostResponseModel(BaseModel):
    post_id: int = Field()


class WallPostResponse(BaseResponse):
    response: "WallPostResponseModel" = Field()


class WallRepostResponseModel(BaseModel):
    success: int = Field(default=1)
    post_id: int = Field()
    reposts_count: int = Field()
    likes_count: int = Field()
    wall_repost_count: typing.Optional[int] = Field(
        default=None,
    )
    mail_repost_count: typing.Optional[int] = Field(
        default=None,
    )


class WallRepostResponse(BaseResponse):
    response: "WallRepostResponseModel" = Field()


class WallSearchExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["WallWallItem"] = Field()
    profiles: typing.List["UsersUserFull"] = Field()
    groups: typing.List["GroupsGroupFull"] = Field()


class WallSearchExtendedResponse(BaseResponse):
    response: "WallSearchExtendedResponseModel" = Field()


class WallSearchResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["WallWallItem"] = Field()


class WallSearchResponse(BaseResponse):
    response: "WallSearchResponseModel" = Field()



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.downloaded_games import *  # noqa: F401,F403  # type: ignore


class DownloadedGamesCategory(BaseCategory):
    async def get_paid_status(
        self,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> DownloadedGamesPaidStatusResponseModel:
        """Method `downloadedGames.getPaidStatus()`

        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("downloadedGames.getPaidStatus", params)
        model = DownloadedGamesPaidStatusResponse
        return model(**response).response


__all__ = ("DownloadedGamesCategory",)



import typing

from vkbottle_types.base_model import Field
from vkbottle_types.objects import (
    PollsBackground,
    PollsFieldsVoters,
    PollsPoll,
    PollsPollExtended,
    PollsVoters,
)
from vkbottle_types.responses.base_response import BaseResponse


class PollsCreateResponse(BaseResponse):
    response: "PollsPoll" = Field()


class PollsGetBackgroundsResponse(BaseResponse):
    response: typing.List["PollsBackground"] = Field()


class PollsGetByIdResponse(BaseResponse):
    response: "PollsPollExtended" = Field()


class PollsGetVotersFieldsResponse(BaseResponse):
    response: typing.List["PollsFieldsVoters"] = Field()


class PollsGetVotersResponse(BaseResponse):
    response: typing.List["PollsVoters"] = Field()


class PollsSavePhotoResponse(BaseResponse):
    response: "PollsBackground" = Field()



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    BoardDefaultOrder,
    BoardTopic,
    BoardTopicComment,
    GroupsGroupFull,
    UsersUserFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class BoardAddTopicResponse(BaseResponse):
    response: int = Field()


class BoardCreateCommentResponse(BaseResponse):
    response: int = Field()


class BoardGetCommentsExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["BoardTopicComment"] = Field()
    profiles: typing.List["UsersUserFull"] = Field()
    groups: typing.List["GroupsGroupFull"] = Field()
    poll: typing.Optional[dict] = Field(
        default=None,
    )
    real_offset: typing.Optional[int] = Field(
        default=None,
    )


class BoardGetCommentsExtendedResponse(BaseResponse):
    response: "BoardGetCommentsExtendedResponseModel" = Field()


class BoardGetCommentsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["BoardTopicComment"] = Field()
    poll: typing.Optional[dict] = Field(
        default=None,
    )
    real_offset: typing.Optional[int] = Field(
        default=None,
    )


class BoardGetCommentsResponse(BaseResponse):
    response: "BoardGetCommentsResponseModel" = Field()


class BoardGetTopicsExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["BoardTopic"] = Field()
    default_order: "BoardDefaultOrder" = Field()
    can_add_topics: bool = Field()
    profiles: typing.List["UsersUserFull"] = Field()
    groups: typing.List["GroupsGroupFull"] = Field()


class BoardGetTopicsExtendedResponse(BaseResponse):
    response: "BoardGetTopicsExtendedResponseModel" = Field()


class BoardGetTopicsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["BoardTopic"] = Field()
    default_order: "BoardDefaultOrder" = Field()
    can_add_topics: bool = Field()


class BoardGetTopicsResponse(BaseResponse):
    response: "BoardGetTopicsResponseModel" = Field()



import typing

from .events import GroupTypes, UserTypes

API_URL: typing.Final[str] = "https://api.vk.com/method/"
API_VERSION: typing.Final[str] = "5.199"


__all__ = (
    "API_URL",
    "API_VERSION",
    "GroupTypes",
    "UserTypes",
)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import PagesWikipage, PagesWikipageFull, PagesWikipageHistory
from vkbottle_types.responses.base import (
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.pages import *  # noqa: F401,F403  # type: ignore


class PagesCategory(BaseCategory):
    async def clear_cache(
        self,
        url: str,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `pages.clearCache()`

        :param url: Address of the page where you need to refesh the cached version
        """

        params = self.get_set_params(locals())
        response = await self.api.request("pages.clearCache", params)
        model = BaseOkResponse
        return model(**response).response

    async def get(
        self,
        _global: typing.Optional[bool] = None,
        need_html: typing.Optional[bool] = None,
        need_source: typing.Optional[bool] = None,
        owner_id: typing.Optional[int] = None,
        page_id: typing.Optional[int] = None,
        site_preview: typing.Optional[bool] = None,
        title: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> "PagesWikipageFull":
        """Method `pages.get()`

        :param global: '1' - to return information about a global wiki page
        :param need_html: '1' - to return the page as HTML,
        :param need_source:
        :param owner_id: Page owner ID.
        :param page_id: Wiki page ID.
        :param site_preview: '1' - resulting wiki page is a preview for the attached link
        :param title: Wiki page title.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("pages.get", params)
        model = PagesGetResponse
        return model(**response).response

    async def get_history(
        self,
        page_id: int,
        group_id: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.List[PagesWikipageHistory]:
        """Method `pages.getHistory()`

        :param page_id: Wiki page ID.
        :param group_id: ID of the community that owns the wiki page.
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("pages.getHistory", params)
        model = PagesGetHistoryResponse
        return model(**response).response

    async def get_titles(
        self,
        group_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> typing.List[PagesWikipage]:
        """Method `pages.getTitles()`

        :param group_id: ID of the community that owns the wiki page.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("pages.getTitles", params)
        model = PagesGetTitlesResponse
        return model(**response).response

    async def get_version(
        self,
        version_id: int,
        group_id: typing.Optional[int] = None,
        need_html: typing.Optional[bool] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> "PagesWikipageFull":
        """Method `pages.getVersion()`

        :param version_id:
        :param group_id: ID of the community that owns the wiki page.
        :param need_html: '1' - to return the page as HTML
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("pages.getVersion", params)
        model = PagesGetVersionResponse
        return model(**response).response

    async def parse_wiki(
        self,
        text: str,
        group_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> str:
        """Method `pages.parseWiki()`

        :param text: Text of the wiki page.
        :param group_id: ID of the group in the context of which this markup is interpreted.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("pages.parseWiki", params)
        model = PagesParseWikiResponse
        return model(**response).response

    async def save(
        self,
        group_id: typing.Optional[int] = None,
        page_id: typing.Optional[int] = None,
        text: typing.Optional[str] = None,
        title: typing.Optional[str] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `pages.save()`

        :param group_id: ID of the community that owns the wiki page.
        :param page_id: Wiki page ID. The 'title' parameter can be passed instead of 'pid'.
        :param text: Text of the wiki page in wiki-format.
        :param title: Wiki page title.
        :param user_id: User ID
        """

        params = self.get_set_params(locals())
        response = await self.api.request("pages.save", params)
        model = PagesSaveResponse
        return model(**response).response

    async def save_access(
        self,
        page_id: int,
        edit: typing.Optional[int] = None,
        group_id: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        view: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `pages.saveAccess()`

        :param page_id: Wiki page ID.
        :param edit: Who can edit the wiki page: '1' - only community members, '2' - all users can edit the page, '0' - only community managers
        :param group_id: ID of the community that owns the wiki page.
        :param user_id:
        :param view: Who can view the wiki page: '1' - only community members, '2' - all users can view the page, '0' - only community managers
        """

        params = self.get_set_params(locals())
        response = await self.api.request("pages.saveAccess", params)
        model = PagesSaveAccessResponse
        return model(**response).response


__all__ = ("PagesCategory",)



from .str_enum import StrEnum


class GroupEventType(StrEnum):
    MESSAGE_NEW = "message_new"
    MESSAGE_REPLY = "message_reply"
    MESSAGE_EDIT = "message_edit"
    MESSAGE_ALLOW = "message_allow"
    MESSAGE_READ = "message_read"
    MESSAGE_DENY = "message_deny"
    MESSAGE_TYPING_STATE = "message_typing_state"
    MESSAGE_REACTION_EVENT = "message_reaction_event"
    MESSAGE_EVENT = "message_event"

    PHOTO_NEW = "photo_new"
    PHOTO_COMMENT_NEW = "photo_comment_new"
    PHOTO_COMMENT_EDIT = "photo_comment_edit"
    PHOTO_COMMENT_RESTORE = "photo_comment_restore"
    PHOTO_COMMENT_DELETE = "photo_comment_delete"

    AUDIO_NEW = "audio_new"

    VIDEO_NEW = "video_new"
    VIDEO_COMMENT_NEW = "video_comment_new"
    VIDEO_COMMENT_EDIT = "video_comment_edit"
    VIDEO_COMMENT_RESTORE = "video_comment_restore"
    VIDEO_COMMENT_DELETE = "video_comment_delete"

    WALL_POST_NEW = "wall_post_new"
    WALL_REPOST = "wall_repost"
    WALL_REPLY_NEW = "wall_reply_new"
    WALL_REPLY_EDIT = "wall_reply_edit"
    WALL_REPLY_RESTORE = "wall_reply_restore"
    WALL_REPLY_DELETE = "wall_reply_delete"

    LIKE_ADD = "like_add"
    LIKE_REMOVE = "like_remove"

    BOARD_POST_NEW = "board_post_new"
    BOARD_POST_EDIT = "board_post_edit"
    BOARD_POST_RESTORE = "board_post_restore"
    BOARD_POST_DELETE = "board_post_delete"

    LEAD_FORMS_NEW = "lead_forms_new"

    MARKET_COMMENT_NEW = "market_comment_new"
    MARKET_COMMENT_EDIT = "market_comment_edit"
    MARKET_COMMENT_RESTORE = "market_comment_restore"
    MARKET_COMMENT_DELETE = "market_comment_delete"

    MARKET_ORDER_NEW = "market_order_new"
    MARKET_ORDER_EDIT = "market_order_edit"

    GROUP_LEAVE = "group_leave"
    GROUP_JOIN = "group_join"

    USER_BLOCK = "user_block"
    USER_UNBLOCK = "user_unblock"

    CONFIRMATION = "confirmation"

    POLL_VOTE_NEW = "poll_vote_new"

    GROUP_OFFICERS_EDIT = "group_officers_edit"

    GROUP_CHANGE_SETTINGS = "group_change_settings"
    GROUP_CHANGE_PHOTO = "group_change_photo"

    VKPAY_TRANSACTION = "vkpay_transaction"
    APP_PAYLOAD = "app_payload"

    DONUT_SUBSCRIPTION_CREATE = "donut_subscription_create"
    DONUT_SUBSCRIPTION_PROLONGED = "donut_subscription_prolonged"
    DONUT_SUBSCRIPTION_EXPIRED = "donut_subscription_expired"
    DONUT_SUBSCRIPTION_CANCELLED = "donut_subscription_cancelled"
    DONUT_SUBSCRIPTION_PRICE_CHANGED = "donut_subscription_price_changed"
    DONUT_MONEY_WITHDRAW = "donut_money_withdraw"
    DONUT_MONEY_WITHDRAW_ERROR = "donut_money_withdraw_error"



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import UsersSubscriptionsItem
from vkbottle_types.responses.base_response import BaseResponse


class LikesAddResponseModel(BaseModel):
    likes: int = Field()


class LikesAddResponse(BaseResponse):
    response: "LikesAddResponseModel" = Field()


class LikesDeleteResponseModel(BaseModel):
    likes: int = Field()


class LikesDeleteResponse(BaseResponse):
    response: "LikesDeleteResponseModel" = Field()


class LikesGetListExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["UsersSubscriptionsItem"] = Field()
    liked_by_author: typing.Optional[dict] = Field(
        default=None,
    )
    liked_by_group: typing.Optional[dict] = Field(
        default=None,
    )


class LikesGetListExtendedResponse(BaseResponse):
    response: "LikesGetListExtendedResponseModel" = Field()


class LikesGetListResponseModel(BaseModel):
    count: int = Field()
    items: typing.List[int] = Field()


class LikesGetListResponse(BaseResponse):
    response: "LikesGetListResponseModel" = Field()


class LikesIsLikedResponseModel(BaseModel):
    liked: bool = Field()
    copied: bool = Field()


class LikesIsLikedResponse(BaseResponse):
    response: "LikesIsLikedResponseModel" = Field()



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.base import (
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.calls import *  # noqa: F401,F403  # type: ignore


class CallsCategory(BaseCategory):
    async def force_finish(
        self,
        call_id: str,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `calls.forceFinish()`

        :param call_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("calls.forceFinish", params)
        model = BaseOkResponse
        return model(**response).response

    async def start(
        self,
        group_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> CallsStartResponseModel:
        """Method `calls.start()`

        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("calls.start", params)
        model = CallsStartResponse
        return model(**response).response


__all__ = ("CallsCategory",)



import typing

from vkbottle_types.base_model import Field
from vkbottle_types.objects import PagesWikipage, PagesWikipageFull, PagesWikipageHistory
from vkbottle_types.responses.base_response import BaseResponse


class PagesGetHistoryResponse(BaseResponse):
    response: typing.List["PagesWikipageHistory"] = Field()


class PagesGetTitlesResponse(BaseResponse):
    response: typing.List["PagesWikipage"] = Field()


class PagesGetVersionResponse(BaseResponse):
    response: "PagesWikipageFull" = Field()


class PagesGetResponse(BaseResponse):
    response: "PagesWikipageFull" = Field()


class PagesParseWikiResponse(BaseResponse):
    response: str = Field()


class PagesSaveAccessResponse(BaseResponse):
    response: int = Field()


class PagesSaveResponse(BaseResponse):
    response: int = Field()



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    GroupsGroupsArray,
    UsersSubscriptionsItem,
    UsersUserFull,
    UsersUsersArray,
)
from vkbottle_types.responses.base_response import BaseResponse


class UsersGetFollowersFieldsResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["UsersUserFull"] = Field()
    friends_count: typing.Optional[int] = Field(
        default=None,
    )


class UsersGetFollowersFieldsResponse(BaseResponse):
    response: "UsersGetFollowersFieldsResponseModel" = Field()


class UsersGetFollowersResponseModel(BaseModel):
    count: int = Field()
    items: typing.List[int] = Field()


class UsersGetFollowersResponse(BaseResponse):
    response: "UsersGetFollowersResponseModel" = Field()


class UsersGetSubscriptionsExtendedResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["UsersSubscriptionsItem"] = Field()


class UsersGetSubscriptionsExtendedResponse(BaseResponse):
    response: "UsersGetSubscriptionsExtendedResponseModel" = Field()


class UsersGetSubscriptionsResponseModel(BaseModel):
    users: "UsersUsersArray" = Field()
    groups: "GroupsGroupsArray" = Field()


class UsersGetSubscriptionsResponse(BaseResponse):
    response: "UsersGetSubscriptionsResponseModel" = Field()


class UsersGetResponse(BaseResponse):
    response: typing.List["UsersUserFull"] = Field()


class UsersSearchResponseModel(BaseModel):
    count: int = Field()
    items: typing.List["UsersUserFull"] = Field()


class UsersSearchResponse(BaseResponse):
    response: "UsersSearchResponseModel" = Field()



import typing

from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    AdswebGetAdCategoriesResponseCategoriesCategory,
    AdswebGetAdUnitsResponseAdUnitsAdUnit,
    AdswebGetFraudHistoryResponseEntriesEntry,
    AdswebGetSitesResponseSitesSite,
    AdswebGetStatisticsResponseItemsItem,
)
from vkbottle_types.responses.base_response import BaseResponse


class AdswebGetAdCategoriesResponseModel(BaseModel):
    categories: typing.List["AdswebGetAdCategoriesResponseCategoriesCategory"] = Field()


class AdswebGetAdCategoriesResponse(BaseResponse):
    response: "AdswebGetAdCategoriesResponseModel" = Field()


class AdswebGetAdUnitCodeResponseModel(BaseModel):
    html: str = Field()


class AdswebGetAdUnitCodeResponse(BaseResponse):
    response: "AdswebGetAdUnitCodeResponseModel" = Field()


class AdswebGetAdUnitsResponseModel(BaseModel):
    count: int = Field()
    ad_units: typing.Optional[typing.List["AdswebGetAdUnitsResponseAdUnitsAdUnit"]] = Field(
        default=None,
    )


class AdswebGetAdUnitsResponse(BaseResponse):
    response: "AdswebGetAdUnitsResponseModel" = Field()


class AdswebGetFraudHistoryResponseModel(BaseModel):
    count: int = Field()
    entries: typing.Optional[typing.List["AdswebGetFraudHistoryResponseEntriesEntry"]] = Field(
        default=None,
    )


class AdswebGetFraudHistoryResponse(BaseResponse):
    response: "AdswebGetFraudHistoryResponseModel" = Field()


class AdswebGetSitesResponseModel(BaseModel):
    count: int = Field()
    sites: typing.Optional[typing.List["AdswebGetSitesResponseSitesSite"]] = Field(
        default=None,
    )


class AdswebGetSitesResponse(BaseResponse):
    response: "AdswebGetSitesResponseModel" = Field()


class AdswebGetStatisticsResponseModel(BaseModel):
    items: typing.List["AdswebGetStatisticsResponseItemsItem"] = Field()
    next_page_id: typing.Optional[str] = Field(
        default=None,
    )


class AdswebGetStatisticsResponse(BaseResponse):
    response: "AdswebGetStatisticsResponseModel" = Field()



from typing import Any, List, Optional, Union, overload

from typing_extensions import Literal

from vkbottle_types.codegen.methods.groups import GroupsCategory  # type: ignore
from vkbottle_types.objects import GroupsMemberStatus, GroupsMemberStatusFull
from vkbottle_types.responses.base import BaseBoolResponse
from vkbottle_types.responses.groups import (
    GetMembersFieldsFilterManagersResponse,
    GetMembersFieldsFilterManagersResponseModel,
    GetMembersFilterManagersResponse,
    GetMembersFilterManagersResponseModel,
    GroupsGetMembersFieldsResponse,
    GroupsGetMembersFieldsResponseModel,
    GroupsGetMembersFilterResponse,
    GroupsGetMembersFilterResponseModel,
    GroupsGetMembersResponse,
    GroupsGetMembersResponseModel,
    GroupsIsMemberExtendedResponse,
    GroupsIsMemberExtendedResponseModel,
    GroupsIsMemberUserIdsExtendedResponse,
    GroupsIsMemberUserIdsResponse,
)


class GroupsCategory(GroupsCategory):
    @overload
    async def get_members(
        self,
        group_id: Optional[Union[str, int]],
        sort: Optional[Literal["id_asc", "id_desc", "time_asc", "time_desc"]] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        fields: Optional[Literal[None]] = ...,
        filter: Optional[Literal["friends", "unsure", "donut"]] = ...,
    ) -> GroupsGetMembersFilterResponseModel: ...

    @overload
    async def get_members(
        self,
        group_id: Optional[str] = None,
        sort: Optional[Literal["id_asc", "id_desc", "time_asc", "time_desc"]] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        fields: List[str] = ...,
        filter: Optional[Literal[None]] = ...,
    ) -> GroupsGetMembersFieldsResponseModel: ...

    @overload
    async def get_members(
        self,
        group_id: Optional[str] = None,
        sort: Optional[Literal["id_asc", "id_desc", "time_asc", "time_desc"]] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        fields: Optional[Literal[None]] = ...,
        filter: Literal["managers"] = ...,
    ) -> GetMembersFilterManagersResponseModel: ...

    @overload
    async def get_members(
        self,
        group_id: Optional[str] = None,
        sort: Optional[Literal["id_asc", "id_desc", "time_asc", "time_desc"]] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        fields: List[str] = ...,
        filter: Literal["managers"] = ...,
    ) -> GetMembersFieldsFilterManagersResponseModel: ...

    async def get_members(
        self,
        group_id=None,
        sort=None,
        offset=None,
        count=None,
        fields=None,
        filter=None,
        **kwargs,
    ) -> Union[
        GetMembersFilterManagersResponseModel,
        GetMembersFieldsFilterManagersResponseModel,
        GroupsGetMembersResponseModel,
        GroupsGetMembersFilterResponseModel,
        GroupsGetMembersFieldsResponseModel,
    ]:
        """Returns a list of community members.

        :param group_id: ID or screen name of the community.
        :param sort: Sort order. Available values: 'id_asc', 'id_desc', 'time_asc', 'time_desc'. 'time_asc' and 'time_desc' are availavle only if the method is called by the group's 'moderator'.
        :param offset: Offset needed to return a specific subset of community members.
        :param count: Number of community members to return.
        :param fields: List of additional fields to be returned. Available values: 'sex, bdate, city, country, photo_50, photo_100, photo_200_orig, photo_200, photo_400_orig, photo_max, photo_max_orig, online, online_mobile, lists, domain, has_mobile, contacts, connections, site, education, universities, schools, can_post, can_see_all_posts, can_see_audio, can_write_private_message, status, last_seen, common_count, relation, relatives, counters'.
        :param filter: *'friends' - only friends in this community will be returned,, *'unsure' - only those who pressed 'I may attend' will be returned (if it's an event).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getMembers", params)
        model = self.get_model(
            (
                ((("filter", "managers"),), GetMembersFilterManagersResponse),
                (
                    (("filter", "managers"), "fields"),
                    GetMembersFieldsFilterManagersResponse,
                ),
                (("fields",), GroupsGetMembersFieldsResponse),
                (("filter",), GroupsGetMembersFilterResponse),
            ),
            default=GroupsGetMembersResponse,
            params=params,
        )
        return model(**response).response

    @overload
    async def is_member(
        self,
        *,
        group_id: Union[int, str],
        user_ids: List[int],
        extended: Literal[True],
    ) -> List[GroupsMemberStatusFull]: ...

    @overload
    async def is_member(
        self,
        *,
        group_id: Union[int, str],
        user_id: int,
        extended: Literal[True],
    ) -> GroupsIsMemberExtendedResponseModel: ...

    @overload
    async def is_member(
        self,
        *,
        group_id: Union[int, str],
        user_ids: List[int],
    ) -> List[GroupsMemberStatus]: ...

    @overload
    async def is_member(
        self,
        *,
        group_id: Union["int", "str"],
        user_id: int,
    ) -> bool: ...

    async def is_member(
        self,
        *,
        group_id: Union[int, str],
        extended: Optional[bool] = None,
        user_ids: Optional[List[int]] = None,
        user_id: Optional[int] = None,
        **kwargs: Any,
    ) -> Union[
        List[GroupsMemberStatus],
        bool,
        GroupsIsMemberExtendedResponseModel,
        List[GroupsMemberStatusFull],
    ]:
        """Method `groups.isMember()`

        :param group_id: ID or screen name of the community.
        :param extended: '1' - to return an extended response with additional fields. By default: '0'.
        :param user_ids: User IDs.
        :param user_id: User ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.isMember", params)
        model = self.get_model(
            (
                (("user_id", "extended"), GroupsIsMemberExtendedResponse),
                (("user_ids", "extended"), GroupsIsMemberUserIdsExtendedResponse),
                (("user_ids",), GroupsIsMemberUserIdsResponse),
            ),
            default=BaseBoolResponse,
            params=params,
        )
        return model(**response).response


__all__ = ("GroupsCategory",)



from .user_events import (
    AddConversationsToFolder,
    Call,
    ChangeFolderOrder,
    ChatEdit,
    ChatInfoEdit,
    ChatTypingState,
    ChatVoiceMessageStates,
    Counter,
    CounterUnreadDialogsInFolders,
    CreateFolder,
    DeleteFolder,
    DialogTypingState,
    FriendAction,
    FriendOffline,
    FriendOnline,
    InRead,
    InstallDialogFlags,
    InstallMessageFlags,
    MessageEdit,
    MessageNew,
    MessagesDelete,
    MessagesRestore,
    NotificationsSettingsChanged,
    OutRead,
    RawUserEvent,
    RemoveConversationsFromFolder,
    RenameFolder,
    ReplaceDialogFlags,
    ReplaceMessageFlags,
    ResetDialogFlags,
    ResetMessageFlags,
    UsersTypingState,
)


class UserTypes:
    RawUserEvent = RawUserEvent
    ReplaceMessageFlags = ReplaceMessageFlags
    InstallMessageFlags = InstallMessageFlags
    ResetMessageFlags = ResetMessageFlags
    MessageNew = MessageNew
    MessagesDelete = MessagesDelete
    MessagesRestore = MessagesRestore
    MessageEdit = MessageEdit
    ChatVoiceMessageStates = ChatVoiceMessageStates
    ChatEdit = ChatEdit
    ChatInfoEdit = ChatInfoEdit
    ChatTypingState = ChatTypingState
    DialogTypingState = DialogTypingState
    UsersTypingState = UsersTypingState
    ResetDialogFlags = ResetDialogFlags
    ReplaceDialogFlags = ReplaceDialogFlags
    InstallDialogFlags = InstallDialogFlags
    FriendOnline = FriendOnline
    FriendOffline = FriendOffline
    Counter = Counter
    Call = Call
    FriendAction = FriendAction
    NotificationsSettingsChanged = NotificationsSettingsChanged
    InRead = InRead
    OutRead = OutRead
    CreateFolder = CreateFolder
    RenameFolder = RenameFolder
    DeleteFolder = DeleteFolder
    AddConversationsToFolder = AddConversationsToFolder
    RemoveConversationsFromFolder = RemoveConversationsFromFolder
    ChangeFolderOrder = ChangeFolderOrder
    CounterUnreadDialogsInFolders = CounterUnreadDialogsInFolders


__all__ = ("UserTypes",)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import NotificationsSendMessageItem
from vkbottle_types.responses.base import (
    BaseBoolResponse,
)
from vkbottle_types.responses.notifications import *  # noqa: F401,F403  # type: ignore


class NotificationsCategory(BaseCategory):
    async def get(
        self,
        count: typing.Optional[int] = None,
        end_time: typing.Optional[int] = None,
        filters: typing.Optional[
            typing.List[
                typing.Literal[
                    "wall", "mentions", "comments", "likes", "reposted", "followers", "friends"
                ]
            ]
        ] = None,
        start_from: typing.Optional[str] = None,
        start_time: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> NotificationsGetResponseModel:
        """Method `notifications.get()`

        :param count: Number of notifications to return.
        :param end_time: Latest timestamp (in Unix time) of a notification to return. By default, the current time.
        :param filters: Type of notifications to return: 'wall' - wall posts, 'mentions' - mentions in wall posts, comments, or topics, 'comments' - comments to wall posts, photos, and videos, 'likes' - likes, 'reposted' - wall posts that are copied from the current user's wall, 'followers' - new followers, 'friends' - accepted friend requests
        :param start_from:
        :param start_time: Earliest timestamp (in Unix time) of a notification to return. By default, 24 hours ago.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("notifications.get", params)
        model = NotificationsGetResponse
        return model(**response).response

    async def mark_as_viewed(
        self,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `notifications.markAsViewed()`"""

        params = self.get_set_params(locals())
        response = await self.api.request("notifications.markAsViewed", params)
        model = BaseBoolResponse
        return model(**response).response

    async def send_message(
        self,
        message: str,
        user_ids: typing.List[int],
        fragment: typing.Optional[str] = None,
        group_id: typing.Optional[int] = None,
        random_id: typing.Optional[int] = None,
        sending_mode: typing.Optional[str] = None,
        **kwargs: typing.Any,
    ) -> typing.List[NotificationsSendMessageItem]:
        """Method `notifications.sendMessage()`

        :param message:
        :param user_ids:
        :param fragment:
        :param group_id:
        :param random_id:
        :param sending_mode: Type of sending (delivering) notifications: 'immediately' - push and bell notifications will be delivered as soon as possible, 'delayed' - push and bell notifications will be delivered in the most comfortable time for the user, 'delayed_push' - only push notifications will be delivered in the most comfortable time, while the bell notifications will be delivered as soon as possible
        """

        params = self.get_set_params(locals())
        response = await self.api.request("notifications.sendMessage", params)
        model = NotificationsSendMessageResponse
        return model(**response).response


__all__ = ("NotificationsCategory",)



from typing import List, Optional

from vkbottle_types.codegen.responses.groups import *  # noqa: F403,F401
from vkbottle_types.objects import GroupsMemberRole, GroupsUserXtrRole
from vkbottle_types.responses.base_response import BaseResponse


class GetMembersFilterManagersResponse(BaseResponse):
    response: "GetMembersFilterManagersResponseModel"


class GetMembersFieldsFilterManagersResponse(BaseResponse):
    response: "GetMembersFieldsFilterManagersResponseModel"


class GetMembersFilterManagersResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["GroupsMemberRole"]] = None


class GetMembersFieldsFilterManagersResponseModel(BaseResponse):
    count: Optional[int] = None
    items: Optional[List["GroupsUserXtrRole"]] = None



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import NotesNote
from vkbottle_types.responses.base import (
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.notes import *  # noqa: F401,F403  # type: ignore


class NotesCategory(BaseCategory):
    async def add(
        self,
        text: str,
        title: str,
        privacy_comment: typing.Optional[typing.List[str]] = None,
        privacy_view: typing.Optional[typing.List[str]] = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `notes.add()`

        :param text: Note text.
        :param title: Note title.
        :param privacy_comment:
        :param privacy_view:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("notes.add", params)
        model = NotesAddResponse
        return model(**response).response

    async def create_comment(
        self,
        message: str,
        note_id: int,
        guid: typing.Optional[str] = None,
        owner_id: typing.Optional[int] = None,
        reply_to: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `notes.createComment()`

        :param message: Comment text.
        :param note_id: Note ID.
        :param guid:
        :param owner_id: Note owner ID.
        :param reply_to: ID of the user to whom the reply is addressed (if the comment is a reply to another comment).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("notes.createComment", params)
        model = NotesCreateCommentResponse
        return model(**response).response

    async def delete(
        self,
        note_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `notes.delete()`

        :param note_id: Note ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("notes.delete", params)
        model = BaseOkResponse
        return model(**response).response

    async def delete_comment(
        self,
        comment_id: int,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `notes.deleteComment()`

        :param comment_id: Comment ID.
        :param owner_id: Note owner ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("notes.deleteComment", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit(
        self,
        note_id: int,
        text: str,
        title: str,
        privacy_comment: typing.Optional[typing.List[str]] = None,
        privacy_view: typing.Optional[typing.List[str]] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `notes.edit()`

        :param note_id: Note ID.
        :param text: Note text.
        :param title: Note title.
        :param privacy_comment:
        :param privacy_view:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("notes.edit", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit_comment(
        self,
        comment_id: int,
        message: str,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `notes.editComment()`

        :param comment_id: Comment ID.
        :param message: New comment text.
        :param owner_id: Note owner ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("notes.editComment", params)
        model = BaseOkResponse
        return model(**response).response

    async def get(
        self,
        count: typing.Optional[int] = None,
        note_ids: typing.Optional[typing.List[int]] = None,
        offset: typing.Optional[int] = None,
        sort: typing.Optional[int] = None,
        user_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> NotesGetResponseModel:
        """Method `notes.get()`

        :param count: Number of notes to return.
        :param note_ids: Note IDs.
        :param offset:
        :param sort:
        :param user_id: Note owner ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("notes.get", params)
        model = NotesGetResponse
        return model(**response).response

    async def get_by_id(
        self,
        note_id: int,
        need_wiki: typing.Optional[bool] = None,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> "NotesNote":
        """Method `notes.getById()`

        :param note_id: Note ID.
        :param need_wiki:
        :param owner_id: Note owner ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("notes.getById", params)
        model = NotesGetByIdResponse
        return model(**response).response

    async def get_comments(
        self,
        note_id: int,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        owner_id: typing.Optional[int] = None,
        sort: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> NotesGetCommentsResponseModel:
        """Method `notes.getComments()`

        :param note_id: Note ID.
        :param count: Number of comments to return.
        :param offset:
        :param owner_id: Note owner ID.
        :param sort:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("notes.getComments", params)
        model = NotesGetCommentsResponse
        return model(**response).response

    async def restore_comment(
        self,
        comment_id: int,
        owner_id: typing.Optional[int] = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `notes.restoreComment()`

        :param comment_id: Comment ID.
        :param owner_id: Note owner ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("notes.restoreComment", params)
        model = BaseOkResponse
        return model(**response).response


__all__ = ("NotesCategory",)
